"""
Enum for all biomes in Minecraft.
"""
class Biome:
    badlands = "badlands"
    badlands_plateau = "badlands_plateau"
    bamboo_jungle = "bamboo_jungle"
    bamboo_jungle_hills = "bamboo_jungle_hills"
    basalt_deltas = "basalt_deltas"
    beach = "beach"
    birch_forest = "birch_forest"
    birch_forest_hills = "birch_forest_hills"
    cold_ocean = "cold_ocean"
    crimson_forest = "crimson_forest"
    dark_forest = "dark_forest"
    dark_forest_hills = "dark_forest_hills"
    deep_cold_ocean = "deep_cold_ocean"
    deep_frozen_ocean = "deep_frozen_ocean"
    deep_lukewarm_ocean = "deep_lukewarm_ocean"
    deep_ocean = "deep_ocean"
    deep_warm_ocean = "deep_warm_ocean"
    desert = "desert"
    desert_hills = "desert_hills"
    desert_lakes = "desert_lakes"
    end_barrens = "end_barrens"
    end_highlands = "end_highlands"
    end_midlands = "end_midlands"
    eroded_badlands = "eroded_badlands"
    flower_forest = "flower_forest"
    forest = "forest"
    frozen_ocean = "frozen_ocean"
    frozen_river = "frozen_river"
    giant_spruce_taiga = "giant_spruce_taiga"
    giant_spruce_taiga_hills = "giant_spruce_taiga_hills"
    giant_tree_taiga = "giant_tree_taiga"
    giant_tree_taiga_hills = "giant_tree_taiga_hills"
    gravelly_mountains = "gravelly_mountains"
    ice_spikes = "ice_spikes"
    jungle = "jungle"
    jungle_edge = "jungle_edge"
    jungle_hills = "jungle_hills"
    lukewarm_ocean = "lukewarm_ocean"
    modified_badlands_plateau = "modified_badlands_plateau"
    modified_gravelly_mountains = "modified_gravelly_mountains"
    modified_jungle = "modified_jungle"
    modified_jungle_edge = "modified_jungle_edge"
    modified_wooded_badlands_plateau = "modified_wooded_badlands_plateau"
    mountain_edge = "mountain_edge"
    mountains = "mountains"
    mushroom_field_shore = "mushroom_field_shore"
    mushroom_fields = "mushroom_fields"
    nether_wastes = "nether_wastes"
    ocean = "ocean"
    plains = "plains"
    river = "river"
    savanna = "savanna"
    savanna_plateau = "savanna_plateau"
    shattered_savanna = "shattered_savanna"
    shattered_savanna_plateau = "shattered_savanna_plateau"
    small_end_islands = "small_end_islands"
    snowy_beach = "snowy_beach"
    snowy_mountains = "snowy_mountains"
    snowy_taiga = "snowy_taiga"
    snowy_taiga_hills = "snowy_taiga_hills"
    snowy_taiga_mountains = "snowy_taiga_mountains"
    snowy_tundra = "snowy_tundra"
    soul_sand_valley = "soul_sand_valley"
    stone_shore = "stone_shore"
    sunflower_plains = "sunflower_plains"
    swamp = "swamp"
    swamp_hills = "swamp_hills"
    taiga = "taiga"
    taiga_hills = "taiga_hills"
    taiga_mountains = "taiga_mountains"
    tall_birch_forest = "tall_birch_forest"
    tall_birch_hills = "tall_birch_hills"
    the_end = "the_end"
    the_void = "the_void"
    warm_ocean = "warm_ocean"
    warped_forest = "warped_forest"
    wooded_badlands_plateau = "wooded_badlands_plateau"
    wooded_hills = "wooded_hills"
    wooded_mountains = "wooded_mountains"
