"""
Enum for item types, and a class for creating items.
"""
from scute import _JsonText
from scute.internal.dictToNBT import dictToNBT

def nbt(**kwargs):
    """
    An optional pretty-print way to define nbt data - `nbt(mytag=Byte(1))` is the same as `{"mytag": Byte(1)}`
    .. include:: ../pdoc/documentation/nbt.md
    """
    return kwargs


class Item:
    def __init__(self, id: str, nbt: dict = None, count=1, name: _JsonText | str = None):
        """
        Creates an item instance. Nbt can be specified manually with nbt= or using a utility, like name=
        Args:
            id: The id of the item, like Item.diamond
            nbt: Optional nbt for the item, like nbt(mytag=Byte(1)) or {"CustomModelData": 3}
            count: Optional count
            name: Utility for setting the name of the item
        """
        if ":" in id:
            self.id = id
        else:
            self.id = "minecraft:" + id
        if name is not None:
            if nbt is None:
                nbt = {}
            if "display" not in nbt:
                nbt["display"] = {}
            nbt["display"]["Name"] = str(name)
        self.nbt = nbt
        self.commandFormat = self.id + dictToNBT(nbt)
        self.count = count

    acacia_boat = "acacia_boat"
    acacia_button = "acacia_button"
    acacia_chest_boat = "acacia_chest_boat"
    acacia_door = "acacia_door"
    acacia_fence = "acacia_fence"
    acacia_fence_gate = "acacia_fence_gate"
    acacia_hanging_sign = "acacia_hanging_sign"
    acacia_leaves = "acacia_leaves"
    acacia_log = "acacia_log"
    acacia_planks = "acacia_planks"
    acacia_pressure_plate = "acacia_pressure_plate"
    acacia_sapling = "acacia_sapling"
    acacia_sign = "acacia_sign"
    acacia_slab = "acacia_slab"
    acacia_stairs = "acacia_stairs"
    acacia_trapdoor = "acacia_trapdoor"
    acacia_wood = "acacia_wood"
    activator_rail = "activator_rail"
    air = "air"
    allay_spawn_egg = "allay_spawn_egg"
    allium = "allium"
    amethyst_block = "amethyst_block"
    amethyst_cluster = "amethyst_cluster"
    amethyst_shard = "amethyst_shard"
    ancient_debris = "ancient_debris"
    andesite = "andesite"
    andesite_slab = "andesite_slab"
    andesite_stairs = "andesite_stairs"
    andesite_wall = "andesite_wall"
    angler_pottery_sherd = "angler_pottery_sherd"
    anvil = "anvil"
    apple = "apple"
    archer_pottery_sherd = "archer_pottery_sherd"
    armor_stand = "armor_stand"
    arms_up_pottery_sherd = "arms_up_pottery_sherd"
    arrow = "arrow"
    axolotl_bucket = "axolotl_bucket"
    axolotl_spawn_egg = "axolotl_spawn_egg"
    azalea = "azalea"
    azalea_leaves = "azalea_leaves"
    azure_bluet = "azure_bluet"
    baked_potato = "baked_potato"
    bamboo = "bamboo"
    bamboo_block = "bamboo_block"
    bamboo_button = "bamboo_button"
    bamboo_chest_raft = "bamboo_chest_raft"
    bamboo_door = "bamboo_door"
    bamboo_fence = "bamboo_fence"
    bamboo_fence_gate = "bamboo_fence_gate"
    bamboo_hanging_sign = "bamboo_hanging_sign"
    bamboo_mosaic = "bamboo_mosaic"
    bamboo_mosaic_slab = "bamboo_mosaic_slab"
    bamboo_mosaic_stairs = "bamboo_mosaic_stairs"
    bamboo_planks = "bamboo_planks"
    bamboo_pressure_plate = "bamboo_pressure_plate"
    bamboo_raft = "bamboo_raft"
    bamboo_sign = "bamboo_sign"
    bamboo_slab = "bamboo_slab"
    bamboo_stairs = "bamboo_stairs"
    bamboo_trapdoor = "bamboo_trapdoor"
    barrel = "barrel"
    barrier = "barrier"
    basalt = "basalt"
    bat_spawn_egg = "bat_spawn_egg"
    beacon = "beacon"
    bedrock = "bedrock"
    bee_nest = "bee_nest"
    bee_spawn_egg = "bee_spawn_egg"
    beef = "beef"
    beehive = "beehive"
    beetroot = "beetroot"
    beetroot_seeds = "beetroot_seeds"
    beetroot_soup = "beetroot_soup"
    bell = "bell"
    big_dripleaf = "big_dripleaf"
    birch_boat = "birch_boat"
    birch_button = "birch_button"
    birch_chest_boat = "birch_chest_boat"
    birch_door = "birch_door"
    birch_fence = "birch_fence"
    birch_fence_gate = "birch_fence_gate"
    birch_hanging_sign = "birch_hanging_sign"
    birch_leaves = "birch_leaves"
    birch_log = "birch_log"
    birch_planks = "birch_planks"
    birch_pressure_plate = "birch_pressure_plate"
    birch_sapling = "birch_sapling"
    birch_sign = "birch_sign"
    birch_slab = "birch_slab"
    birch_stairs = "birch_stairs"
    birch_trapdoor = "birch_trapdoor"
    birch_wood = "birch_wood"
    black_banner = "black_banner"
    black_bed = "black_bed"
    black_candle = "black_candle"
    black_carpet = "black_carpet"
    black_concrete = "black_concrete"
    black_concrete_powder = "black_concrete_powder"
    black_dye = "black_dye"
    black_glazed_terracotta = "black_glazed_terracotta"
    black_shulker_box = "black_shulker_box"
    black_stained_glass = "black_stained_glass"
    black_stained_glass_pane = "black_stained_glass_pane"
    black_terracotta = "black_terracotta"
    black_wool = "black_wool"
    blackstone = "blackstone"
    blackstone_slab = "blackstone_slab"
    blackstone_stairs = "blackstone_stairs"
    blackstone_wall = "blackstone_wall"
    blade_pottery_sherd = "blade_pottery_sherd"
    blast_furnace = "blast_furnace"
    blaze_powder = "blaze_powder"
    blaze_rod = "blaze_rod"
    blaze_spawn_egg = "blaze_spawn_egg"
    blue_banner = "blue_banner"
    blue_bed = "blue_bed"
    blue_candle = "blue_candle"
    blue_carpet = "blue_carpet"
    blue_concrete = "blue_concrete"
    blue_concrete_powder = "blue_concrete_powder"
    blue_dye = "blue_dye"
    blue_glazed_terracotta = "blue_glazed_terracotta"
    blue_ice = "blue_ice"
    blue_orchid = "blue_orchid"
    blue_shulker_box = "blue_shulker_box"
    blue_stained_glass = "blue_stained_glass"
    blue_stained_glass_pane = "blue_stained_glass_pane"
    blue_terracotta = "blue_terracotta"
    blue_wool = "blue_wool"
    bone = "bone"
    bone_block = "bone_block"
    bone_meal = "bone_meal"
    book = "book"
    bookshelf = "bookshelf"
    bow = "bow"
    bowl = "bowl"
    brain_coral = "brain_coral"
    brain_coral_block = "brain_coral_block"
    brain_coral_fan = "brain_coral_fan"
    bread = "bread"
    brewer_pottery_sherd = "brewer_pottery_sherd"
    brewing_stand = "brewing_stand"
    brick = "brick"
    brick_slab = "brick_slab"
    brick_stairs = "brick_stairs"
    brick_wall = "brick_wall"
    bricks = "bricks"
    brown_banner = "brown_banner"
    brown_bed = "brown_bed"
    brown_candle = "brown_candle"
    brown_carpet = "brown_carpet"
    brown_concrete = "brown_concrete"
    brown_concrete_powder = "brown_concrete_powder"
    brown_dye = "brown_dye"
    brown_glazed_terracotta = "brown_glazed_terracotta"
    brown_mushroom = "brown_mushroom"
    brown_mushroom_block = "brown_mushroom_block"
    brown_shulker_box = "brown_shulker_box"
    brown_stained_glass = "brown_stained_glass"
    brown_stained_glass_pane = "brown_stained_glass_pane"
    brown_terracotta = "brown_terracotta"
    brown_wool = "brown_wool"
    brush = "brush"
    bubble_coral = "bubble_coral"
    bubble_coral_block = "bubble_coral_block"
    bubble_coral_fan = "bubble_coral_fan"
    bucket = "bucket"
    budding_amethyst = "budding_amethyst"
    bundle = "bundle"
    burn_pottery_sherd = "burn_pottery_sherd"
    cactus = "cactus"
    cake = "cake"
    calcite = "calcite"
    calibrated_sculk_sensor = "calibrated_sculk_sensor"
    camel_spawn_egg = "camel_spawn_egg"
    campfire = "campfire"
    candle = "candle"
    carrot = "carrot"
    carrot_on_a_stick = "carrot_on_a_stick"
    cartography_table = "cartography_table"
    carved_pumpkin = "carved_pumpkin"
    cat_spawn_egg = "cat_spawn_egg"
    cauldron = "cauldron"
    cave_spider_spawn_egg = "cave_spider_spawn_egg"
    chain = "chain"
    chain_command_block = "chain_command_block"
    chainmail_boots = "chainmail_boots"
    chainmail_chestplate = "chainmail_chestplate"
    chainmail_helmet = "chainmail_helmet"
    chainmail_leggings = "chainmail_leggings"
    charcoal = "charcoal"
    cherry_boat = "cherry_boat"
    cherry_button = "cherry_button"
    cherry_chest_boat = "cherry_chest_boat"
    cherry_door = "cherry_door"
    cherry_fence = "cherry_fence"
    cherry_fence_gate = "cherry_fence_gate"
    cherry_hanging_sign = "cherry_hanging_sign"
    cherry_leaves = "cherry_leaves"
    cherry_log = "cherry_log"
    cherry_planks = "cherry_planks"
    cherry_pressure_plate = "cherry_pressure_plate"
    cherry_sapling = "cherry_sapling"
    cherry_sign = "cherry_sign"
    cherry_slab = "cherry_slab"
    cherry_stairs = "cherry_stairs"
    cherry_trapdoor = "cherry_trapdoor"
    cherry_wood = "cherry_wood"
    chest = "chest"
    chest_minecart = "chest_minecart"
    chicken = "chicken"
    chicken_spawn_egg = "chicken_spawn_egg"
    chipped_anvil = "chipped_anvil"
    chiseled_bookshelf = "chiseled_bookshelf"
    chiseled_deepslate = "chiseled_deepslate"
    chiseled_nether_bricks = "chiseled_nether_bricks"
    chiseled_polished_blackstone = "chiseled_polished_blackstone"
    chiseled_quartz_block = "chiseled_quartz_block"
    chiseled_red_sandstone = "chiseled_red_sandstone"
    chiseled_sandstone = "chiseled_sandstone"
    chiseled_stone_bricks = "chiseled_stone_bricks"
    chorus_flower = "chorus_flower"
    chorus_fruit = "chorus_fruit"
    chorus_plant = "chorus_plant"
    clay = "clay"
    clay_ball = "clay_ball"
    clock = "clock"
    coal = "coal"
    coal_block = "coal_block"
    coal_ore = "coal_ore"
    coarse_dirt = "coarse_dirt"
    coast_armor_trim_smithing_template = "coast_armor_trim_smithing_template"
    cobbled_deepslate = "cobbled_deepslate"
    cobbled_deepslate_slab = "cobbled_deepslate_slab"
    cobbled_deepslate_stairs = "cobbled_deepslate_stairs"
    cobbled_deepslate_wall = "cobbled_deepslate_wall"
    cobblestone = "cobblestone"
    cobblestone_slab = "cobblestone_slab"
    cobblestone_stairs = "cobblestone_stairs"
    cobblestone_wall = "cobblestone_wall"
    cobweb = "cobweb"
    cocoa_beans = "cocoa_beans"
    cod = "cod"
    cod_bucket = "cod_bucket"
    cod_spawn_egg = "cod_spawn_egg"
    command_block = "command_block"
    command_block_minecart = "command_block_minecart"
    comparator = "comparator"
    compass = "compass"
    composter = "composter"
    conduit = "conduit"
    cooked_beef = "cooked_beef"
    cooked_chicken = "cooked_chicken"
    cooked_cod = "cooked_cod"
    cooked_mutton = "cooked_mutton"
    cooked_porkchop = "cooked_porkchop"
    cooked_rabbit = "cooked_rabbit"
    cooked_salmon = "cooked_salmon"
    cookie = "cookie"
    copper_block = "copper_block"
    copper_ingot = "copper_ingot"
    copper_ore = "copper_ore"
    cornflower = "cornflower"
    cow_spawn_egg = "cow_spawn_egg"
    cracked_deepslate_bricks = "cracked_deepslate_bricks"
    cracked_deepslate_tiles = "cracked_deepslate_tiles"
    cracked_nether_bricks = "cracked_nether_bricks"
    cracked_polished_blackstone_bricks = "cracked_polished_blackstone_bricks"
    cracked_stone_bricks = "cracked_stone_bricks"
    crafting_table = "crafting_table"
    creeper_banner_pattern = "creeper_banner_pattern"
    creeper_head = "creeper_head"
    creeper_spawn_egg = "creeper_spawn_egg"
    crimson_button = "crimson_button"
    crimson_door = "crimson_door"
    crimson_fence = "crimson_fence"
    crimson_fence_gate = "crimson_fence_gate"
    crimson_fungus = "crimson_fungus"
    crimson_hanging_sign = "crimson_hanging_sign"
    crimson_hyphae = "crimson_hyphae"
    crimson_nylium = "crimson_nylium"
    crimson_planks = "crimson_planks"
    crimson_pressure_plate = "crimson_pressure_plate"
    crimson_roots = "crimson_roots"
    crimson_sign = "crimson_sign"
    crimson_slab = "crimson_slab"
    crimson_stairs = "crimson_stairs"
    crimson_stem = "crimson_stem"
    crimson_trapdoor = "crimson_trapdoor"
    crossbow = "crossbow"
    crying_obsidian = "crying_obsidian"
    cut_copper = "cut_copper"
    cut_copper_slab = "cut_copper_slab"
    cut_copper_stairs = "cut_copper_stairs"
    cut_red_sandstone = "cut_red_sandstone"
    cut_red_sandstone_slab = "cut_red_sandstone_slab"
    cut_sandstone = "cut_sandstone"
    cut_sandstone_slab = "cut_sandstone_slab"
    cyan_banner = "cyan_banner"
    cyan_bed = "cyan_bed"
    cyan_candle = "cyan_candle"
    cyan_carpet = "cyan_carpet"
    cyan_concrete = "cyan_concrete"
    cyan_concrete_powder = "cyan_concrete_powder"
    cyan_dye = "cyan_dye"
    cyan_glazed_terracotta = "cyan_glazed_terracotta"
    cyan_shulker_box = "cyan_shulker_box"
    cyan_stained_glass = "cyan_stained_glass"
    cyan_stained_glass_pane = "cyan_stained_glass_pane"
    cyan_terracotta = "cyan_terracotta"
    cyan_wool = "cyan_wool"
    damaged_anvil = "damaged_anvil"
    dandelion = "dandelion"
    danger_pottery_sherd = "danger_pottery_sherd"
    dark_oak_boat = "dark_oak_boat"
    dark_oak_button = "dark_oak_button"
    dark_oak_chest_boat = "dark_oak_chest_boat"
    dark_oak_door = "dark_oak_door"
    dark_oak_fence = "dark_oak_fence"
    dark_oak_fence_gate = "dark_oak_fence_gate"
    dark_oak_hanging_sign = "dark_oak_hanging_sign"
    dark_oak_leaves = "dark_oak_leaves"
    dark_oak_log = "dark_oak_log"
    dark_oak_planks = "dark_oak_planks"
    dark_oak_pressure_plate = "dark_oak_pressure_plate"
    dark_oak_sapling = "dark_oak_sapling"
    dark_oak_sign = "dark_oak_sign"
    dark_oak_slab = "dark_oak_slab"
    dark_oak_stairs = "dark_oak_stairs"
    dark_oak_trapdoor = "dark_oak_trapdoor"
    dark_oak_wood = "dark_oak_wood"
    dark_prismarine = "dark_prismarine"
    dark_prismarine_slab = "dark_prismarine_slab"
    dark_prismarine_stairs = "dark_prismarine_stairs"
    daylight_detector = "daylight_detector"
    dead_brain_coral = "dead_brain_coral"
    dead_brain_coral_block = "dead_brain_coral_block"
    dead_brain_coral_fan = "dead_brain_coral_fan"
    dead_bubble_coral = "dead_bubble_coral"
    dead_bubble_coral_block = "dead_bubble_coral_block"
    dead_bubble_coral_fan = "dead_bubble_coral_fan"
    dead_bush = "dead_bush"
    dead_fire_coral = "dead_fire_coral"
    dead_fire_coral_block = "dead_fire_coral_block"
    dead_fire_coral_fan = "dead_fire_coral_fan"
    dead_horn_coral = "dead_horn_coral"
    dead_horn_coral_block = "dead_horn_coral_block"
    dead_horn_coral_fan = "dead_horn_coral_fan"
    dead_tube_coral = "dead_tube_coral"
    dead_tube_coral_block = "dead_tube_coral_block"
    dead_tube_coral_fan = "dead_tube_coral_fan"
    debug_stick = "debug_stick"
    decorated_pot = "decorated_pot"
    deepslate = "deepslate"
    deepslate_brick_slab = "deepslate_brick_slab"
    deepslate_brick_stairs = "deepslate_brick_stairs"
    deepslate_brick_wall = "deepslate_brick_wall"
    deepslate_bricks = "deepslate_bricks"
    deepslate_coal_ore = "deepslate_coal_ore"
    deepslate_copper_ore = "deepslate_copper_ore"
    deepslate_diamond_ore = "deepslate_diamond_ore"
    deepslate_emerald_ore = "deepslate_emerald_ore"
    deepslate_gold_ore = "deepslate_gold_ore"
    deepslate_iron_ore = "deepslate_iron_ore"
    deepslate_lapis_ore = "deepslate_lapis_ore"
    deepslate_redstone_ore = "deepslate_redstone_ore"
    deepslate_tile_slab = "deepslate_tile_slab"
    deepslate_tile_stairs = "deepslate_tile_stairs"
    deepslate_tile_wall = "deepslate_tile_wall"
    deepslate_tiles = "deepslate_tiles"
    detector_rail = "detector_rail"
    diamond = "diamond"
    diamond_axe = "diamond_axe"
    diamond_block = "diamond_block"
    diamond_boots = "diamond_boots"
    diamond_chestplate = "diamond_chestplate"
    diamond_helmet = "diamond_helmet"
    diamond_hoe = "diamond_hoe"
    diamond_horse_armor = "diamond_horse_armor"
    diamond_leggings = "diamond_leggings"
    diamond_ore = "diamond_ore"
    diamond_pickaxe = "diamond_pickaxe"
    diamond_shovel = "diamond_shovel"
    diamond_sword = "diamond_sword"
    diorite = "diorite"
    diorite_slab = "diorite_slab"
    diorite_stairs = "diorite_stairs"
    diorite_wall = "diorite_wall"
    dirt = "dirt"
    dirt_path = "dirt_path"
    disc_fragment_5 = "disc_fragment_5"
    dispenser = "dispenser"
    dolphin_spawn_egg = "dolphin_spawn_egg"
    donkey_spawn_egg = "donkey_spawn_egg"
    dragon_breath = "dragon_breath"
    dragon_egg = "dragon_egg"
    dragon_head = "dragon_head"
    dried_kelp = "dried_kelp"
    dried_kelp_block = "dried_kelp_block"
    dripstone_block = "dripstone_block"
    dropper = "dropper"
    drowned_spawn_egg = "drowned_spawn_egg"
    dune_armor_trim_smithing_template = "dune_armor_trim_smithing_template"
    echo_shard = "echo_shard"
    egg = "egg"
    elder_guardian_spawn_egg = "elder_guardian_spawn_egg"
    elytra = "elytra"
    emerald = "emerald"
    emerald_block = "emerald_block"
    emerald_ore = "emerald_ore"
    enchanted_book = "enchanted_book"
    enchanted_golden_apple = "enchanted_golden_apple"
    enchanting_table = "enchanting_table"
    end_crystal = "end_crystal"
    end_portal_frame = "end_portal_frame"
    end_rod = "end_rod"
    end_stone = "end_stone"
    end_stone_brick_slab = "end_stone_brick_slab"
    end_stone_brick_stairs = "end_stone_brick_stairs"
    end_stone_brick_wall = "end_stone_brick_wall"
    end_stone_bricks = "end_stone_bricks"
    ender_chest = "ender_chest"
    ender_dragon_spawn_egg = "ender_dragon_spawn_egg"
    ender_eye = "ender_eye"
    ender_pearl = "ender_pearl"
    enderman_spawn_egg = "enderman_spawn_egg"
    endermite_spawn_egg = "endermite_spawn_egg"
    evoker_spawn_egg = "evoker_spawn_egg"
    experience_bottle = "experience_bottle"
    explorer_pottery_sherd = "explorer_pottery_sherd"
    exposed_copper = "exposed_copper"
    exposed_cut_copper = "exposed_cut_copper"
    exposed_cut_copper_slab = "exposed_cut_copper_slab"
    exposed_cut_copper_stairs = "exposed_cut_copper_stairs"
    eye_armor_trim_smithing_template = "eye_armor_trim_smithing_template"
    farmland = "farmland"
    feather = "feather"
    fermented_spider_eye = "fermented_spider_eye"
    fern = "fern"
    filled_map = "filled_map"
    fire_charge = "fire_charge"
    fire_coral = "fire_coral"
    fire_coral_block = "fire_coral_block"
    fire_coral_fan = "fire_coral_fan"
    firework_rocket = "firework_rocket"
    firework_star = "firework_star"
    fishing_rod = "fishing_rod"
    fletching_table = "fletching_table"
    flint = "flint"
    flint_and_steel = "flint_and_steel"
    flower_banner_pattern = "flower_banner_pattern"
    flower_pot = "flower_pot"
    flowering_azalea = "flowering_azalea"
    flowering_azalea_leaves = "flowering_azalea_leaves"
    fox_spawn_egg = "fox_spawn_egg"
    friend_pottery_sherd = "friend_pottery_sherd"
    frog_spawn_egg = "frog_spawn_egg"
    frogspawn = "frogspawn"
    furnace = "furnace"
    furnace_minecart = "furnace_minecart"
    ghast_spawn_egg = "ghast_spawn_egg"
    ghast_tear = "ghast_tear"
    gilded_blackstone = "gilded_blackstone"
    glass = "glass"
    glass_bottle = "glass_bottle"
    glass_pane = "glass_pane"
    glistering_melon_slice = "glistering_melon_slice"
    globe_banner_pattern = "globe_banner_pattern"
    glow_berries = "glow_berries"
    glow_ink_sac = "glow_ink_sac"
    glow_item_frame = "glow_item_frame"
    glow_lichen = "glow_lichen"
    glow_squid_spawn_egg = "glow_squid_spawn_egg"
    glowstone = "glowstone"
    glowstone_dust = "glowstone_dust"
    goat_horn = "goat_horn"
    goat_spawn_egg = "goat_spawn_egg"
    gold_block = "gold_block"
    gold_ingot = "gold_ingot"
    gold_nugget = "gold_nugget"
    gold_ore = "gold_ore"
    golden_apple = "golden_apple"
    golden_axe = "golden_axe"
    golden_boots = "golden_boots"
    golden_carrot = "golden_carrot"
    golden_chestplate = "golden_chestplate"
    golden_helmet = "golden_helmet"
    golden_hoe = "golden_hoe"
    golden_horse_armor = "golden_horse_armor"
    golden_leggings = "golden_leggings"
    golden_pickaxe = "golden_pickaxe"
    golden_shovel = "golden_shovel"
    golden_sword = "golden_sword"
    granite = "granite"
    granite_slab = "granite_slab"
    granite_stairs = "granite_stairs"
    granite_wall = "granite_wall"
    grass = "grass"
    grass_block = "grass_block"
    gravel = "gravel"
    gray_banner = "gray_banner"
    gray_bed = "gray_bed"
    gray_candle = "gray_candle"
    gray_carpet = "gray_carpet"
    gray_concrete = "gray_concrete"
    gray_concrete_powder = "gray_concrete_powder"
    gray_dye = "gray_dye"
    gray_glazed_terracotta = "gray_glazed_terracotta"
    gray_shulker_box = "gray_shulker_box"
    gray_stained_glass = "gray_stained_glass"
    gray_stained_glass_pane = "gray_stained_glass_pane"
    gray_terracotta = "gray_terracotta"
    gray_wool = "gray_wool"
    green_banner = "green_banner"
    green_bed = "green_bed"
    green_candle = "green_candle"
    green_carpet = "green_carpet"
    green_concrete = "green_concrete"
    green_concrete_powder = "green_concrete_powder"
    green_dye = "green_dye"
    green_glazed_terracotta = "green_glazed_terracotta"
    green_shulker_box = "green_shulker_box"
    green_stained_glass = "green_stained_glass"
    green_stained_glass_pane = "green_stained_glass_pane"
    green_terracotta = "green_terracotta"
    green_wool = "green_wool"
    grindstone = "grindstone"
    guardian_spawn_egg = "guardian_spawn_egg"
    gunpowder = "gunpowder"
    hanging_roots = "hanging_roots"
    hay_block = "hay_block"
    heart_of_the_sea = "heart_of_the_sea"
    heart_pottery_sherd = "heart_pottery_sherd"
    heartbreak_pottery_sherd = "heartbreak_pottery_sherd"
    heavy_weighted_pressure_plate = "heavy_weighted_pressure_plate"
    hoglin_spawn_egg = "hoglin_spawn_egg"
    honey_block = "honey_block"
    honey_bottle = "honey_bottle"
    honeycomb = "honeycomb"
    honeycomb_block = "honeycomb_block"
    hopper = "hopper"
    hopper_minecart = "hopper_minecart"
    horn_coral = "horn_coral"
    horn_coral_block = "horn_coral_block"
    horn_coral_fan = "horn_coral_fan"
    horse_spawn_egg = "horse_spawn_egg"
    host_armor_trim_smithing_template = "host_armor_trim_smithing_template"
    howl_pottery_sherd = "howl_pottery_sherd"
    husk_spawn_egg = "husk_spawn_egg"
    ice = "ice"
    infested_chiseled_stone_bricks = "infested_chiseled_stone_bricks"
    infested_cobblestone = "infested_cobblestone"
    infested_cracked_stone_bricks = "infested_cracked_stone_bricks"
    infested_deepslate = "infested_deepslate"
    infested_mossy_stone_bricks = "infested_mossy_stone_bricks"
    infested_stone = "infested_stone"
    infested_stone_bricks = "infested_stone_bricks"
    ink_sac = "ink_sac"
    iron_axe = "iron_axe"
    iron_bars = "iron_bars"
    iron_block = "iron_block"
    iron_boots = "iron_boots"
    iron_chestplate = "iron_chestplate"
    iron_door = "iron_door"
    iron_golem_spawn_egg = "iron_golem_spawn_egg"
    iron_helmet = "iron_helmet"
    iron_hoe = "iron_hoe"
    iron_horse_armor = "iron_horse_armor"
    iron_ingot = "iron_ingot"
    iron_leggings = "iron_leggings"
    iron_nugget = "iron_nugget"
    iron_ore = "iron_ore"
    iron_pickaxe = "iron_pickaxe"
    iron_shovel = "iron_shovel"
    iron_sword = "iron_sword"
    iron_trapdoor = "iron_trapdoor"
    item_frame = "item_frame"
    jack_o_lantern = "jack_o_lantern"
    jigsaw = "jigsaw"
    jukebox = "jukebox"
    jungle_boat = "jungle_boat"
    jungle_button = "jungle_button"
    jungle_chest_boat = "jungle_chest_boat"
    jungle_door = "jungle_door"
    jungle_fence = "jungle_fence"
    jungle_fence_gate = "jungle_fence_gate"
    jungle_hanging_sign = "jungle_hanging_sign"
    jungle_leaves = "jungle_leaves"
    jungle_log = "jungle_log"
    jungle_planks = "jungle_planks"
    jungle_pressure_plate = "jungle_pressure_plate"
    jungle_sapling = "jungle_sapling"
    jungle_sign = "jungle_sign"
    jungle_slab = "jungle_slab"
    jungle_stairs = "jungle_stairs"
    jungle_trapdoor = "jungle_trapdoor"
    jungle_wood = "jungle_wood"
    kelp = "kelp"
    knowledge_book = "knowledge_book"
    ladder = "ladder"
    lantern = "lantern"
    lapis_block = "lapis_block"
    lapis_lazuli = "lapis_lazuli"
    lapis_ore = "lapis_ore"
    large_amethyst_bud = "large_amethyst_bud"
    large_fern = "large_fern"
    lava_bucket = "lava_bucket"
    lead = "lead"
    leather = "leather"
    leather_boots = "leather_boots"
    leather_chestplate = "leather_chestplate"
    leather_helmet = "leather_helmet"
    leather_horse_armor = "leather_horse_armor"
    leather_leggings = "leather_leggings"
    lectern = "lectern"
    lever = "lever"
    light = "light"
    light_blue_banner = "light_blue_banner"
    light_blue_bed = "light_blue_bed"
    light_blue_candle = "light_blue_candle"
    light_blue_carpet = "light_blue_carpet"
    light_blue_concrete = "light_blue_concrete"
    light_blue_concrete_powder = "light_blue_concrete_powder"
    light_blue_dye = "light_blue_dye"
    light_blue_glazed_terracotta = "light_blue_glazed_terracotta"
    light_blue_shulker_box = "light_blue_shulker_box"
    light_blue_stained_glass = "light_blue_stained_glass"
    light_blue_stained_glass_pane = "light_blue_stained_glass_pane"
    light_blue_terracotta = "light_blue_terracotta"
    light_blue_wool = "light_blue_wool"
    light_gray_banner = "light_gray_banner"
    light_gray_bed = "light_gray_bed"
    light_gray_candle = "light_gray_candle"
    light_gray_carpet = "light_gray_carpet"
    light_gray_concrete = "light_gray_concrete"
    light_gray_concrete_powder = "light_gray_concrete_powder"
    light_gray_dye = "light_gray_dye"
    light_gray_glazed_terracotta = "light_gray_glazed_terracotta"
    light_gray_shulker_box = "light_gray_shulker_box"
    light_gray_stained_glass = "light_gray_stained_glass"
    light_gray_stained_glass_pane = "light_gray_stained_glass_pane"
    light_gray_terracotta = "light_gray_terracotta"
    light_gray_wool = "light_gray_wool"
    light_weighted_pressure_plate = "light_weighted_pressure_plate"
    lightning_rod = "lightning_rod"
    lilac = "lilac"
    lily_of_the_valley = "lily_of_the_valley"
    lily_pad = "lily_pad"
    lime_banner = "lime_banner"
    lime_bed = "lime_bed"
    lime_candle = "lime_candle"
    lime_carpet = "lime_carpet"
    lime_concrete = "lime_concrete"
    lime_concrete_powder = "lime_concrete_powder"
    lime_dye = "lime_dye"
    lime_glazed_terracotta = "lime_glazed_terracotta"
    lime_shulker_box = "lime_shulker_box"
    lime_stained_glass = "lime_stained_glass"
    lime_stained_glass_pane = "lime_stained_glass_pane"
    lime_terracotta = "lime_terracotta"
    lime_wool = "lime_wool"
    lingering_potion = "lingering_potion"
    llama_spawn_egg = "llama_spawn_egg"
    lodestone = "lodestone"
    loom = "loom"
    magenta_banner = "magenta_banner"
    magenta_bed = "magenta_bed"
    magenta_candle = "magenta_candle"
    magenta_carpet = "magenta_carpet"
    magenta_concrete = "magenta_concrete"
    magenta_concrete_powder = "magenta_concrete_powder"
    magenta_dye = "magenta_dye"
    magenta_glazed_terracotta = "magenta_glazed_terracotta"
    magenta_shulker_box = "magenta_shulker_box"
    magenta_stained_glass = "magenta_stained_glass"
    magenta_stained_glass_pane = "magenta_stained_glass_pane"
    magenta_terracotta = "magenta_terracotta"
    magenta_wool = "magenta_wool"
    magma_block = "magma_block"
    magma_cream = "magma_cream"
    magma_cube_spawn_egg = "magma_cube_spawn_egg"
    mangrove_boat = "mangrove_boat"
    mangrove_button = "mangrove_button"
    mangrove_chest_boat = "mangrove_chest_boat"
    mangrove_door = "mangrove_door"
    mangrove_fence = "mangrove_fence"
    mangrove_fence_gate = "mangrove_fence_gate"
    mangrove_hanging_sign = "mangrove_hanging_sign"
    mangrove_leaves = "mangrove_leaves"
    mangrove_log = "mangrove_log"
    mangrove_planks = "mangrove_planks"
    mangrove_pressure_plate = "mangrove_pressure_plate"
    mangrove_propagule = "mangrove_propagule"
    mangrove_roots = "mangrove_roots"
    mangrove_sign = "mangrove_sign"
    mangrove_slab = "mangrove_slab"
    mangrove_stairs = "mangrove_stairs"
    mangrove_trapdoor = "mangrove_trapdoor"
    mangrove_wood = "mangrove_wood"
    map = "map"
    medium_amethyst_bud = "medium_amethyst_bud"
    melon = "melon"
    melon_seeds = "melon_seeds"
    melon_slice = "melon_slice"
    milk_bucket = "milk_bucket"
    minecart = "minecart"
    miner_pottery_sherd = "miner_pottery_sherd"
    mojang_banner_pattern = "mojang_banner_pattern"
    mooshroom_spawn_egg = "mooshroom_spawn_egg"
    moss_block = "moss_block"
    moss_carpet = "moss_carpet"
    mossy_cobblestone = "mossy_cobblestone"
    mossy_cobblestone_slab = "mossy_cobblestone_slab"
    mossy_cobblestone_stairs = "mossy_cobblestone_stairs"
    mossy_cobblestone_wall = "mossy_cobblestone_wall"
    mossy_stone_brick_slab = "mossy_stone_brick_slab"
    mossy_stone_brick_stairs = "mossy_stone_brick_stairs"
    mossy_stone_brick_wall = "mossy_stone_brick_wall"
    mossy_stone_bricks = "mossy_stone_bricks"
    mourner_pottery_sherd = "mourner_pottery_sherd"
    mud = "mud"
    mud_brick_slab = "mud_brick_slab"
    mud_brick_stairs = "mud_brick_stairs"
    mud_brick_wall = "mud_brick_wall"
    mud_bricks = "mud_bricks"
    muddy_mangrove_roots = "muddy_mangrove_roots"
    mule_spawn_egg = "mule_spawn_egg"
    mushroom_stem = "mushroom_stem"
    mushroom_stew = "mushroom_stew"
    music_disc_11 = "music_disc_11"
    music_disc_13 = "music_disc_13"
    music_disc_5 = "music_disc_5"
    music_disc_blocks = "music_disc_blocks"
    music_disc_cat = "music_disc_cat"
    music_disc_chirp = "music_disc_chirp"
    music_disc_far = "music_disc_far"
    music_disc_mall = "music_disc_mall"
    music_disc_mellohi = "music_disc_mellohi"
    music_disc_otherside = "music_disc_otherside"
    music_disc_pigstep = "music_disc_pigstep"
    music_disc_relic = "music_disc_relic"
    music_disc_stal = "music_disc_stal"
    music_disc_strad = "music_disc_strad"
    music_disc_wait = "music_disc_wait"
    music_disc_ward = "music_disc_ward"
    mutton = "mutton"
    mycelium = "mycelium"
    name_tag = "name_tag"
    nautilus_shell = "nautilus_shell"
    nether_brick = "nether_brick"
    nether_brick_fence = "nether_brick_fence"
    nether_brick_slab = "nether_brick_slab"
    nether_brick_stairs = "nether_brick_stairs"
    nether_brick_wall = "nether_brick_wall"
    nether_bricks = "nether_bricks"
    nether_gold_ore = "nether_gold_ore"
    nether_quartz_ore = "nether_quartz_ore"
    nether_sprouts = "nether_sprouts"
    nether_star = "nether_star"
    nether_wart = "nether_wart"
    nether_wart_block = "nether_wart_block"
    netherite_axe = "netherite_axe"
    netherite_block = "netherite_block"
    netherite_boots = "netherite_boots"
    netherite_chestplate = "netherite_chestplate"
    netherite_helmet = "netherite_helmet"
    netherite_hoe = "netherite_hoe"
    netherite_ingot = "netherite_ingot"
    netherite_leggings = "netherite_leggings"
    netherite_pickaxe = "netherite_pickaxe"
    netherite_scrap = "netherite_scrap"
    netherite_shovel = "netherite_shovel"
    netherite_sword = "netherite_sword"
    netherite_upgrade_smithing_template = "netherite_upgrade_smithing_template"
    netherrack = "netherrack"
    note_block = "note_block"
    oak_boat = "oak_boat"
    oak_button = "oak_button"
    oak_chest_boat = "oak_chest_boat"
    oak_door = "oak_door"
    oak_fence = "oak_fence"
    oak_fence_gate = "oak_fence_gate"
    oak_hanging_sign = "oak_hanging_sign"
    oak_leaves = "oak_leaves"
    oak_log = "oak_log"
    oak_planks = "oak_planks"
    oak_pressure_plate = "oak_pressure_plate"
    oak_sapling = "oak_sapling"
    oak_sign = "oak_sign"
    oak_slab = "oak_slab"
    oak_stairs = "oak_stairs"
    oak_trapdoor = "oak_trapdoor"
    oak_wood = "oak_wood"
    observer = "observer"
    obsidian = "obsidian"
    ocelot_spawn_egg = "ocelot_spawn_egg"
    ochre_froglight = "ochre_froglight"
    orange_banner = "orange_banner"
    orange_bed = "orange_bed"
    orange_candle = "orange_candle"
    orange_carpet = "orange_carpet"
    orange_concrete = "orange_concrete"
    orange_concrete_powder = "orange_concrete_powder"
    orange_dye = "orange_dye"
    orange_glazed_terracotta = "orange_glazed_terracotta"
    orange_shulker_box = "orange_shulker_box"
    orange_stained_glass = "orange_stained_glass"
    orange_stained_glass_pane = "orange_stained_glass_pane"
    orange_terracotta = "orange_terracotta"
    orange_tulip = "orange_tulip"
    orange_wool = "orange_wool"
    oxeye_daisy = "oxeye_daisy"
    oxidized_copper = "oxidized_copper"
    oxidized_cut_copper = "oxidized_cut_copper"
    oxidized_cut_copper_slab = "oxidized_cut_copper_slab"
    oxidized_cut_copper_stairs = "oxidized_cut_copper_stairs"
    packed_ice = "packed_ice"
    packed_mud = "packed_mud"
    painting = "painting"
    panda_spawn_egg = "panda_spawn_egg"
    paper = "paper"
    parrot_spawn_egg = "parrot_spawn_egg"
    pearlescent_froglight = "pearlescent_froglight"
    peony = "peony"
    petrified_oak_slab = "petrified_oak_slab"
    phantom_membrane = "phantom_membrane"
    phantom_spawn_egg = "phantom_spawn_egg"
    pig_spawn_egg = "pig_spawn_egg"
    piglin_banner_pattern = "piglin_banner_pattern"
    piglin_brute_spawn_egg = "piglin_brute_spawn_egg"
    piglin_head = "piglin_head"
    piglin_spawn_egg = "piglin_spawn_egg"
    pillager_spawn_egg = "pillager_spawn_egg"
    pink_banner = "pink_banner"
    pink_bed = "pink_bed"
    pink_candle = "pink_candle"
    pink_carpet = "pink_carpet"
    pink_concrete = "pink_concrete"
    pink_concrete_powder = "pink_concrete_powder"
    pink_dye = "pink_dye"
    pink_glazed_terracotta = "pink_glazed_terracotta"
    pink_petals = "pink_petals"
    pink_shulker_box = "pink_shulker_box"
    pink_stained_glass = "pink_stained_glass"
    pink_stained_glass_pane = "pink_stained_glass_pane"
    pink_terracotta = "pink_terracotta"
    pink_tulip = "pink_tulip"
    pink_wool = "pink_wool"
    piston = "piston"
    pitcher_plant = "pitcher_plant"
    pitcher_pod = "pitcher_pod"
    player_head = "player_head"
    plenty_pottery_sherd = "plenty_pottery_sherd"
    podzol = "podzol"
    pointed_dripstone = "pointed_dripstone"
    poisonous_potato = "poisonous_potato"
    polar_bear_spawn_egg = "polar_bear_spawn_egg"
    polished_andesite = "polished_andesite"
    polished_andesite_slab = "polished_andesite_slab"
    polished_andesite_stairs = "polished_andesite_stairs"
    polished_basalt = "polished_basalt"
    polished_blackstone = "polished_blackstone"
    polished_blackstone_brick_slab = "polished_blackstone_brick_slab"
    polished_blackstone_brick_stairs = "polished_blackstone_brick_stairs"
    polished_blackstone_brick_wall = "polished_blackstone_brick_wall"
    polished_blackstone_bricks = "polished_blackstone_bricks"
    polished_blackstone_button = "polished_blackstone_button"
    polished_blackstone_pressure_plate = "polished_blackstone_pressure_plate"
    polished_blackstone_slab = "polished_blackstone_slab"
    polished_blackstone_stairs = "polished_blackstone_stairs"
    polished_blackstone_wall = "polished_blackstone_wall"
    polished_deepslate = "polished_deepslate"
    polished_deepslate_slab = "polished_deepslate_slab"
    polished_deepslate_stairs = "polished_deepslate_stairs"
    polished_deepslate_wall = "polished_deepslate_wall"
    polished_diorite = "polished_diorite"
    polished_diorite_slab = "polished_diorite_slab"
    polished_diorite_stairs = "polished_diorite_stairs"
    polished_granite = "polished_granite"
    polished_granite_slab = "polished_granite_slab"
    polished_granite_stairs = "polished_granite_stairs"
    popped_chorus_fruit = "popped_chorus_fruit"
    poppy = "poppy"
    porkchop = "porkchop"
    potato = "potato"
    potion = "potion"
    powder_snow_bucket = "powder_snow_bucket"
    powered_rail = "powered_rail"
    prismarine = "prismarine"
    prismarine_brick_slab = "prismarine_brick_slab"
    prismarine_brick_stairs = "prismarine_brick_stairs"
    prismarine_bricks = "prismarine_bricks"
    prismarine_crystals = "prismarine_crystals"
    prismarine_shard = "prismarine_shard"
    prismarine_slab = "prismarine_slab"
    prismarine_stairs = "prismarine_stairs"
    prismarine_wall = "prismarine_wall"
    prize_pottery_sherd = "prize_pottery_sherd"
    pufferfish = "pufferfish"
    pufferfish_bucket = "pufferfish_bucket"
    pufferfish_spawn_egg = "pufferfish_spawn_egg"
    pumpkin = "pumpkin"
    pumpkin_pie = "pumpkin_pie"
    pumpkin_seeds = "pumpkin_seeds"
    purple_banner = "purple_banner"
    purple_bed = "purple_bed"
    purple_candle = "purple_candle"
    purple_carpet = "purple_carpet"
    purple_concrete = "purple_concrete"
    purple_concrete_powder = "purple_concrete_powder"
    purple_dye = "purple_dye"
    purple_glazed_terracotta = "purple_glazed_terracotta"
    purple_shulker_box = "purple_shulker_box"
    purple_stained_glass = "purple_stained_glass"
    purple_stained_glass_pane = "purple_stained_glass_pane"
    purple_terracotta = "purple_terracotta"
    purple_wool = "purple_wool"
    purpur_block = "purpur_block"
    purpur_pillar = "purpur_pillar"
    purpur_slab = "purpur_slab"
    purpur_stairs = "purpur_stairs"
    quartz = "quartz"
    quartz_block = "quartz_block"
    quartz_bricks = "quartz_bricks"
    quartz_pillar = "quartz_pillar"
    quartz_slab = "quartz_slab"
    quartz_stairs = "quartz_stairs"
    rabbit = "rabbit"
    rabbit_foot = "rabbit_foot"
    rabbit_hide = "rabbit_hide"
    rabbit_spawn_egg = "rabbit_spawn_egg"
    rabbit_stew = "rabbit_stew"
    rail = "rail"
    raiser_armor_trim_smithing_template = "raiser_armor_trim_smithing_template"
    ravager_spawn_egg = "ravager_spawn_egg"
    raw_copper = "raw_copper"
    raw_copper_block = "raw_copper_block"
    raw_gold = "raw_gold"
    raw_gold_block = "raw_gold_block"
    raw_iron = "raw_iron"
    raw_iron_block = "raw_iron_block"
    recovery_compass = "recovery_compass"
    red_banner = "red_banner"
    red_bed = "red_bed"
    red_candle = "red_candle"
    red_carpet = "red_carpet"
    red_concrete = "red_concrete"
    red_concrete_powder = "red_concrete_powder"
    red_dye = "red_dye"
    red_glazed_terracotta = "red_glazed_terracotta"
    red_mushroom = "red_mushroom"
    red_mushroom_block = "red_mushroom_block"
    red_nether_brick_slab = "red_nether_brick_slab"
    red_nether_brick_stairs = "red_nether_brick_stairs"
    red_nether_brick_wall = "red_nether_brick_wall"
    red_nether_bricks = "red_nether_bricks"
    red_sand = "red_sand"
    red_sandstone = "red_sandstone"
    red_sandstone_slab = "red_sandstone_slab"
    red_sandstone_stairs = "red_sandstone_stairs"
    red_sandstone_wall = "red_sandstone_wall"
    red_shulker_box = "red_shulker_box"
    red_stained_glass = "red_stained_glass"
    red_stained_glass_pane = "red_stained_glass_pane"
    red_terracotta = "red_terracotta"
    red_tulip = "red_tulip"
    red_wool = "red_wool"
    redstone = "redstone"
    redstone_block = "redstone_block"
    redstone_lamp = "redstone_lamp"
    redstone_ore = "redstone_ore"
    redstone_torch = "redstone_torch"
    reinforced_deepslate = "reinforced_deepslate"
    repeater = "repeater"
    repeating_command_block = "repeating_command_block"
    respawn_anchor = "respawn_anchor"
    rib_armor_trim_smithing_template = "rib_armor_trim_smithing_template"
    rooted_dirt = "rooted_dirt"
    rose_bush = "rose_bush"
    rotten_flesh = "rotten_flesh"
    saddle = "saddle"
    salmon = "salmon"
    salmon_bucket = "salmon_bucket"
    salmon_spawn_egg = "salmon_spawn_egg"
    sand = "sand"
    sandstone = "sandstone"
    sandstone_slab = "sandstone_slab"
    sandstone_stairs = "sandstone_stairs"
    sandstone_wall = "sandstone_wall"
    scaffolding = "scaffolding"
    sculk = "sculk"
    sculk_catalyst = "sculk_catalyst"
    sculk_sensor = "sculk_sensor"
    sculk_shrieker = "sculk_shrieker"
    sculk_vein = "sculk_vein"
    scute = "scute"
    sea_lantern = "sea_lantern"
    sea_pickle = "sea_pickle"
    seagrass = "seagrass"
    sentry_armor_trim_smithing_template = "sentry_armor_trim_smithing_template"
    shaper_armor_trim_smithing_template = "shaper_armor_trim_smithing_template"
    sheaf_pottery_sherd = "sheaf_pottery_sherd"
    shears = "shears"
    sheep_spawn_egg = "sheep_spawn_egg"
    shelter_pottery_sherd = "shelter_pottery_sherd"
    shield = "shield"
    shroomlight = "shroomlight"
    shulker_box = "shulker_box"
    shulker_shell = "shulker_shell"
    shulker_spawn_egg = "shulker_spawn_egg"
    silence_armor_trim_smithing_template = "silence_armor_trim_smithing_template"
    silverfish_spawn_egg = "silverfish_spawn_egg"
    skeleton_horse_spawn_egg = "skeleton_horse_spawn_egg"
    skeleton_skull = "skeleton_skull"
    skeleton_spawn_egg = "skeleton_spawn_egg"
    skull_banner_pattern = "skull_banner_pattern"
    skull_pottery_sherd = "skull_pottery_sherd"
    slime_ball = "slime_ball"
    slime_block = "slime_block"
    slime_spawn_egg = "slime_spawn_egg"
    small_amethyst_bud = "small_amethyst_bud"
    small_dripleaf = "small_dripleaf"
    smithing_table = "smithing_table"
    smoker = "smoker"
    smooth_basalt = "smooth_basalt"
    smooth_quartz = "smooth_quartz"
    smooth_quartz_slab = "smooth_quartz_slab"
    smooth_quartz_stairs = "smooth_quartz_stairs"
    smooth_red_sandstone = "smooth_red_sandstone"
    smooth_red_sandstone_slab = "smooth_red_sandstone_slab"
    smooth_red_sandstone_stairs = "smooth_red_sandstone_stairs"
    smooth_sandstone = "smooth_sandstone"
    smooth_sandstone_slab = "smooth_sandstone_slab"
    smooth_sandstone_stairs = "smooth_sandstone_stairs"
    smooth_stone = "smooth_stone"
    smooth_stone_slab = "smooth_stone_slab"
    sniffer_egg = "sniffer_egg"
    sniffer_spawn_egg = "sniffer_spawn_egg"
    snort_pottery_sherd = "snort_pottery_sherd"
    snout_armor_trim_smithing_template = "snout_armor_trim_smithing_template"
    snow = "snow"
    snow_block = "snow_block"
    snow_golem_spawn_egg = "snow_golem_spawn_egg"
    snowball = "snowball"
    soul_campfire = "soul_campfire"
    soul_lantern = "soul_lantern"
    soul_sand = "soul_sand"
    soul_soil = "soul_soil"
    soul_torch = "soul_torch"
    spawner = "spawner"
    spectral_arrow = "spectral_arrow"
    spider_eye = "spider_eye"
    spider_spawn_egg = "spider_spawn_egg"
    spire_armor_trim_smithing_template = "spire_armor_trim_smithing_template"
    splash_potion = "splash_potion"
    sponge = "sponge"
    spore_blossom = "spore_blossom"
    spruce_boat = "spruce_boat"
    spruce_button = "spruce_button"
    spruce_chest_boat = "spruce_chest_boat"
    spruce_door = "spruce_door"
    spruce_fence = "spruce_fence"
    spruce_fence_gate = "spruce_fence_gate"
    spruce_hanging_sign = "spruce_hanging_sign"
    spruce_leaves = "spruce_leaves"
    spruce_log = "spruce_log"
    spruce_planks = "spruce_planks"
    spruce_pressure_plate = "spruce_pressure_plate"
    spruce_sapling = "spruce_sapling"
    spruce_sign = "spruce_sign"
    spruce_slab = "spruce_slab"
    spruce_stairs = "spruce_stairs"
    spruce_trapdoor = "spruce_trapdoor"
    spruce_wood = "spruce_wood"
    spyglass = "spyglass"
    squid_spawn_egg = "squid_spawn_egg"
    stick = "stick"
    sticky_piston = "sticky_piston"
    stone = "stone"
    stone_axe = "stone_axe"
    stone_brick_slab = "stone_brick_slab"
    stone_brick_stairs = "stone_brick_stairs"
    stone_brick_wall = "stone_brick_wall"
    stone_bricks = "stone_bricks"
    stone_button = "stone_button"
    stone_hoe = "stone_hoe"
    stone_pickaxe = "stone_pickaxe"
    stone_pressure_plate = "stone_pressure_plate"
    stone_shovel = "stone_shovel"
    stone_slab = "stone_slab"
    stone_stairs = "stone_stairs"
    stone_sword = "stone_sword"
    stonecutter = "stonecutter"
    stray_spawn_egg = "stray_spawn_egg"
    strider_spawn_egg = "strider_spawn_egg"
    string = "string"
    stripped_acacia_log = "stripped_acacia_log"
    stripped_acacia_wood = "stripped_acacia_wood"
    stripped_bamboo_block = "stripped_bamboo_block"
    stripped_birch_log = "stripped_birch_log"
    stripped_birch_wood = "stripped_birch_wood"
    stripped_cherry_log = "stripped_cherry_log"
    stripped_cherry_wood = "stripped_cherry_wood"
    stripped_crimson_hyphae = "stripped_crimson_hyphae"
    stripped_crimson_stem = "stripped_crimson_stem"
    stripped_dark_oak_log = "stripped_dark_oak_log"
    stripped_dark_oak_wood = "stripped_dark_oak_wood"
    stripped_jungle_log = "stripped_jungle_log"
    stripped_jungle_wood = "stripped_jungle_wood"
    stripped_mangrove_log = "stripped_mangrove_log"
    stripped_mangrove_wood = "stripped_mangrove_wood"
    stripped_oak_log = "stripped_oak_log"
    stripped_oak_wood = "stripped_oak_wood"
    stripped_spruce_log = "stripped_spruce_log"
    stripped_spruce_wood = "stripped_spruce_wood"
    stripped_warped_hyphae = "stripped_warped_hyphae"
    stripped_warped_stem = "stripped_warped_stem"
    structure_block = "structure_block"
    structure_void = "structure_void"
    sugar = "sugar"
    sugar_cane = "sugar_cane"
    sunflower = "sunflower"
    suspicious_gravel = "suspicious_gravel"
    suspicious_sand = "suspicious_sand"
    suspicious_stew = "suspicious_stew"
    sweet_berries = "sweet_berries"
    tadpole_bucket = "tadpole_bucket"
    tadpole_spawn_egg = "tadpole_spawn_egg"
    tall_grass = "tall_grass"
    target = "target"
    terracotta = "terracotta"
    tide_armor_trim_smithing_template = "tide_armor_trim_smithing_template"
    tinted_glass = "tinted_glass"
    tipped_arrow = "tipped_arrow"
    tnt = "tnt"
    tnt_minecart = "tnt_minecart"
    torch = "torch"
    torchflower = "torchflower"
    torchflower_seeds = "torchflower_seeds"
    totem_of_undying = "totem_of_undying"
    trader_llama_spawn_egg = "trader_llama_spawn_egg"
    trapped_chest = "trapped_chest"
    trident = "trident"
    tripwire_hook = "tripwire_hook"
    tropical_fish = "tropical_fish"
    tropical_fish_bucket = "tropical_fish_bucket"
    tropical_fish_spawn_egg = "tropical_fish_spawn_egg"
    tube_coral = "tube_coral"
    tube_coral_block = "tube_coral_block"
    tube_coral_fan = "tube_coral_fan"
    tuff = "tuff"
    turtle_egg = "turtle_egg"
    turtle_helmet = "turtle_helmet"
    turtle_spawn_egg = "turtle_spawn_egg"
    twisting_vines = "twisting_vines"
    verdant_froglight = "verdant_froglight"
    vex_armor_trim_smithing_template = "vex_armor_trim_smithing_template"
    vex_spawn_egg = "vex_spawn_egg"
    villager_spawn_egg = "villager_spawn_egg"
    vindicator_spawn_egg = "vindicator_spawn_egg"
    vine = "vine"
    wandering_trader_spawn_egg = "wandering_trader_spawn_egg"
    ward_armor_trim_smithing_template = "ward_armor_trim_smithing_template"
    warden_spawn_egg = "warden_spawn_egg"
    warped_button = "warped_button"
    warped_door = "warped_door"
    warped_fence = "warped_fence"
    warped_fence_gate = "warped_fence_gate"
    warped_fungus = "warped_fungus"
    warped_fungus_on_a_stick = "warped_fungus_on_a_stick"
    warped_hanging_sign = "warped_hanging_sign"
    warped_hyphae = "warped_hyphae"
    warped_nylium = "warped_nylium"
    warped_planks = "warped_planks"
    warped_pressure_plate = "warped_pressure_plate"
    warped_roots = "warped_roots"
    warped_sign = "warped_sign"
    warped_slab = "warped_slab"
    warped_stairs = "warped_stairs"
    warped_stem = "warped_stem"
    warped_trapdoor = "warped_trapdoor"
    warped_wart_block = "warped_wart_block"
    water_bucket = "water_bucket"
    waxed_copper_block = "waxed_copper_block"
    waxed_cut_copper = "waxed_cut_copper"
    waxed_cut_copper_slab = "waxed_cut_copper_slab"
    waxed_cut_copper_stairs = "waxed_cut_copper_stairs"
    waxed_exposed_copper = "waxed_exposed_copper"
    waxed_exposed_cut_copper = "waxed_exposed_cut_copper"
    waxed_exposed_cut_copper_slab = "waxed_exposed_cut_copper_slab"
    waxed_exposed_cut_copper_stairs = "waxed_exposed_cut_copper_stairs"
    waxed_oxidized_copper = "waxed_oxidized_copper"
    waxed_oxidized_cut_copper = "waxed_oxidized_cut_copper"
    waxed_oxidized_cut_copper_slab = "waxed_oxidized_cut_copper_slab"
    waxed_oxidized_cut_copper_stairs = "waxed_oxidized_cut_copper_stairs"
    waxed_weathered_copper = "waxed_weathered_copper"
    waxed_weathered_cut_copper = "waxed_weathered_cut_copper"
    waxed_weathered_cut_copper_slab = "waxed_weathered_cut_copper_slab"
    waxed_weathered_cut_copper_stairs = "waxed_weathered_cut_copper_stairs"
    wayfinder_armor_trim_smithing_template = "wayfinder_armor_trim_smithing_template"
    weathered_copper = "weathered_copper"
    weathered_cut_copper = "weathered_cut_copper"
    weathered_cut_copper_slab = "weathered_cut_copper_slab"
    weathered_cut_copper_stairs = "weathered_cut_copper_stairs"
    weeping_vines = "weeping_vines"
    wet_sponge = "wet_sponge"
    wheat = "wheat"
    wheat_seeds = "wheat_seeds"
    white_banner = "white_banner"
    white_bed = "white_bed"
    white_candle = "white_candle"
    white_carpet = "white_carpet"
    white_concrete = "white_concrete"
    white_concrete_powder = "white_concrete_powder"
    white_dye = "white_dye"
    white_glazed_terracotta = "white_glazed_terracotta"
    white_shulker_box = "white_shulker_box"
    white_stained_glass = "white_stained_glass"
    white_stained_glass_pane = "white_stained_glass_pane"
    white_terracotta = "white_terracotta"
    white_tulip = "white_tulip"
    white_wool = "white_wool"
    wild_armor_trim_smithing_template = "wild_armor_trim_smithing_template"
    witch_spawn_egg = "witch_spawn_egg"
    wither_rose = "wither_rose"
    wither_skeleton_skull = "wither_skeleton_skull"
    wither_skeleton_spawn_egg = "wither_skeleton_spawn_egg"
    wither_spawn_egg = "wither_spawn_egg"
    wolf_spawn_egg = "wolf_spawn_egg"
    wooden_axe = "wooden_axe"
    wooden_hoe = "wooden_hoe"
    wooden_pickaxe = "wooden_pickaxe"
    wooden_shovel = "wooden_shovel"
    wooden_sword = "wooden_sword"
    writable_book = "writable_book"
    written_book = "written_book"
    yellow_banner = "yellow_banner"
    yellow_bed = "yellow_bed"
    yellow_candle = "yellow_candle"
    yellow_carpet = "yellow_carpet"
    yellow_concrete = "yellow_concrete"
    yellow_concrete_powder = "yellow_concrete_powder"
    yellow_dye = "yellow_dye"
    yellow_glazed_terracotta = "yellow_glazed_terracotta"
    yellow_shulker_box = "yellow_shulker_box"
    yellow_stained_glass = "yellow_stained_glass"
    yellow_stained_glass_pane = "yellow_stained_glass_pane"
    yellow_terracotta = "yellow_terracotta"
    yellow_wool = "yellow_wool"
    zoglin_spawn_egg = "zoglin_spawn_egg"
    zombie_head = "zombie_head"
    zombie_horse_spawn_egg = "zombie_horse_spawn_egg"
    zombie_spawn_egg = "zombie_spawn_egg"
    zombie_villager_spawn_egg = "zombie_villager_spawn_egg"
    zombified_piglin_spawn_egg = "zombified_piglin_spawn_egg"
