"""
Enum for all heightmaps in Minecraft.
"""
class Heightmap:
    world_surface = "world_surface"
    motion_blocking = "motion_blocking"
    motion_blocking_no_leaves = "motion_blocking_no_leaves"
    ocean_floor = "ocean_floor"
