"""
Enum for all relations in the game.
"""
class Relation:
    attacker = "attacker"
    controller = "controller"
    leasher = "leasher"
    origin = "origin"
    owner = "owner"
    passengers = "passengers"
    target = "target"
    vehicle = "vehicle"
