"""
Enum and class for blocks.
"""
class Block:
    def __init__(self, name: str, nbt: dict = None):
        self.id = name
        self.nbt = nbt

    acacia_button = "acacia_button"
    acacia_door = "acacia_door"
    acacia_fence = "acacia_fence"
    acacia_fence_gate = "acacia_fence_gate"
    acacia_hanging_sign = "acacia_hanging_sign"
    acacia_leaves = "acacia_leaves"
    acacia_log = "acacia_log"
    acacia_planks = "acacia_planks"
    acacia_pressure_plate = "acacia_pressure_plate"
    acacia_sapling = "acacia_sapling"
    acacia_sign = "acacia_sign"
    acacia_slab = "acacia_slab"
    acacia_stairs = "acacia_stairs"
    acacia_trapdoor = "acacia_trapdoor"
    acacia_wall_hanging_sign = "acacia_wall_hanging_sign"
    acacia_wall_sign = "acacia_wall_sign"
    acacia_wood = "acacia_wood"
    activator_rail = "activator_rail"
    air = "air"
    allium = "allium"
    amethyst_block = "amethyst_block"
    amethyst_cluster = "amethyst_cluster"
    ancient_debris = "ancient_debris"
    andesite = "andesite"
    andesite_slab = "andesite_slab"
    andesite_stairs = "andesite_stairs"
    andesite_wall = "andesite_wall"
    anvil = "anvil"
    attached_melon_stem = "attached_melon_stem"
    attached_pumpkin_stem = "attached_pumpkin_stem"
    azalea = "azalea"
    azalea_leaves = "azalea_leaves"
    azure_bluet = "azure_bluet"
    bamboo = "bamboo"
    bamboo_block = "bamboo_block"
    bamboo_button = "bamboo_button"
    bamboo_door = "bamboo_door"
    bamboo_fence = "bamboo_fence"
    bamboo_fence_gate = "bamboo_fence_gate"
    bamboo_hanging_sign = "bamboo_hanging_sign"
    bamboo_mosaic = "bamboo_mosaic"
    bamboo_mosaic_slab = "bamboo_mosaic_slab"
    bamboo_mosaic_stairs = "bamboo_mosaic_stairs"
    bamboo_planks = "bamboo_planks"
    bamboo_pressure_plate = "bamboo_pressure_plate"
    bamboo_sapling = "bamboo_sapling"
    bamboo_sign = "bamboo_sign"
    bamboo_slab = "bamboo_slab"
    bamboo_stairs = "bamboo_stairs"
    bamboo_trapdoor = "bamboo_trapdoor"
    bamboo_wall_hanging_sign = "bamboo_wall_hanging_sign"
    bamboo_wall_sign = "bamboo_wall_sign"
    barrel = "barrel"
    barrier = "barrier"
    basalt = "basalt"
    beacon = "beacon"
    bedrock = "bedrock"
    bee_nest = "bee_nest"
    beehive = "beehive"
    beetroots = "beetroots"
    bell = "bell"
    big_dripleaf = "big_dripleaf"
    big_dripleaf_stem = "big_dripleaf_stem"
    birch_button = "birch_button"
    birch_door = "birch_door"
    birch_fence = "birch_fence"
    birch_fence_gate = "birch_fence_gate"
    birch_hanging_sign = "birch_hanging_sign"
    birch_leaves = "birch_leaves"
    birch_log = "birch_log"
    birch_planks = "birch_planks"
    birch_pressure_plate = "birch_pressure_plate"
    birch_sapling = "birch_sapling"
    birch_sign = "birch_sign"
    birch_slab = "birch_slab"
    birch_stairs = "birch_stairs"
    birch_trapdoor = "birch_trapdoor"
    birch_wall_hanging_sign = "birch_wall_hanging_sign"
    birch_wall_sign = "birch_wall_sign"
    birch_wood = "birch_wood"
    black_banner = "black_banner"
    black_bed = "black_bed"
    black_candle = "black_candle"
    black_candle_cake = "black_candle_cake"
    black_carpet = "black_carpet"
    black_concrete = "black_concrete"
    black_concrete_powder = "black_concrete_powder"
    black_glazed_terracotta = "black_glazed_terracotta"
    black_shulker_box = "black_shulker_box"
    black_stained_glass = "black_stained_glass"
    black_stained_glass_pane = "black_stained_glass_pane"
    black_terracotta = "black_terracotta"
    black_wall_banner = "black_wall_banner"
    black_wool = "black_wool"
    blackstone = "blackstone"
    blackstone_slab = "blackstone_slab"
    blackstone_stairs = "blackstone_stairs"
    blackstone_wall = "blackstone_wall"
    blast_furnace = "blast_furnace"
    blue_banner = "blue_banner"
    blue_bed = "blue_bed"
    blue_candle = "blue_candle"
    blue_candle_cake = "blue_candle_cake"
    blue_carpet = "blue_carpet"
    blue_concrete = "blue_concrete"
    blue_concrete_powder = "blue_concrete_powder"
    blue_glazed_terracotta = "blue_glazed_terracotta"
    blue_ice = "blue_ice"
    blue_orchid = "blue_orchid"
    blue_shulker_box = "blue_shulker_box"
    blue_stained_glass = "blue_stained_glass"
    blue_stained_glass_pane = "blue_stained_glass_pane"
    blue_terracotta = "blue_terracotta"
    blue_wall_banner = "blue_wall_banner"
    blue_wool = "blue_wool"
    bone_block = "bone_block"
    bookshelf = "bookshelf"
    brain_coral = "brain_coral"
    brain_coral_block = "brain_coral_block"
    brain_coral_fan = "brain_coral_fan"
    brain_coral_wall_fan = "brain_coral_wall_fan"
    brewing_stand = "brewing_stand"
    brick_slab = "brick_slab"
    brick_stairs = "brick_stairs"
    brick_wall = "brick_wall"
    bricks = "bricks"
    brown_banner = "brown_banner"
    brown_bed = "brown_bed"
    brown_candle = "brown_candle"
    brown_candle_cake = "brown_candle_cake"
    brown_carpet = "brown_carpet"
    brown_concrete = "brown_concrete"
    brown_concrete_powder = "brown_concrete_powder"
    brown_glazed_terracotta = "brown_glazed_terracotta"
    brown_mushroom = "brown_mushroom"
    brown_mushroom_block = "brown_mushroom_block"
    brown_shulker_box = "brown_shulker_box"
    brown_stained_glass = "brown_stained_glass"
    brown_stained_glass_pane = "brown_stained_glass_pane"
    brown_terracotta = "brown_terracotta"
    brown_wall_banner = "brown_wall_banner"
    brown_wool = "brown_wool"
    bubble_column = "bubble_column"
    bubble_coral = "bubble_coral"
    bubble_coral_block = "bubble_coral_block"
    bubble_coral_fan = "bubble_coral_fan"
    bubble_coral_wall_fan = "bubble_coral_wall_fan"
    budding_amethyst = "budding_amethyst"
    cactus = "cactus"
    cake = "cake"
    calcite = "calcite"
    calibrated_sculk_sensor = "calibrated_sculk_sensor"
    campfire = "campfire"
    candle = "candle"
    candle_cake = "candle_cake"
    carrots = "carrots"
    cartography_table = "cartography_table"
    carved_pumpkin = "carved_pumpkin"
    cauldron = "cauldron"
    cave_air = "cave_air"
    cave_vines = "cave_vines"
    cave_vines_plant = "cave_vines_plant"
    chain = "chain"
    chain_command_block = "chain_command_block"
    cherry_button = "cherry_button"
    cherry_door = "cherry_door"
    cherry_fence = "cherry_fence"
    cherry_fence_gate = "cherry_fence_gate"
    cherry_hanging_sign = "cherry_hanging_sign"
    cherry_leaves = "cherry_leaves"
    cherry_log = "cherry_log"
    cherry_planks = "cherry_planks"
    cherry_pressure_plate = "cherry_pressure_plate"
    cherry_sapling = "cherry_sapling"
    cherry_sign = "cherry_sign"
    cherry_slab = "cherry_slab"
    cherry_stairs = "cherry_stairs"
    cherry_trapdoor = "cherry_trapdoor"
    cherry_wall_hanging_sign = "cherry_wall_hanging_sign"
    cherry_wall_sign = "cherry_wall_sign"
    cherry_wood = "cherry_wood"
    chest = "chest"
    chipped_anvil = "chipped_anvil"
    chiseled_bookshelf = "chiseled_bookshelf"
    chiseled_deepslate = "chiseled_deepslate"
    chiseled_nether_bricks = "chiseled_nether_bricks"
    chiseled_polished_blackstone = "chiseled_polished_blackstone"
    chiseled_quartz_block = "chiseled_quartz_block"
    chiseled_red_sandstone = "chiseled_red_sandstone"
    chiseled_sandstone = "chiseled_sandstone"
    chiseled_stone_bricks = "chiseled_stone_bricks"
    chorus_flower = "chorus_flower"
    chorus_plant = "chorus_plant"
    clay = "clay"
    coal_block = "coal_block"
    coal_ore = "coal_ore"
    coarse_dirt = "coarse_dirt"
    cobbled_deepslate = "cobbled_deepslate"
    cobbled_deepslate_slab = "cobbled_deepslate_slab"
    cobbled_deepslate_stairs = "cobbled_deepslate_stairs"
    cobbled_deepslate_wall = "cobbled_deepslate_wall"
    cobblestone = "cobblestone"
    cobblestone_slab = "cobblestone_slab"
    cobblestone_stairs = "cobblestone_stairs"
    cobblestone_wall = "cobblestone_wall"
    cobweb = "cobweb"
    cocoa = "cocoa"
    command_block = "command_block"
    comparator = "comparator"
    composter = "composter"
    conduit = "conduit"
    copper_block = "copper_block"
    copper_ore = "copper_ore"
    cornflower = "cornflower"
    cracked_deepslate_bricks = "cracked_deepslate_bricks"
    cracked_deepslate_tiles = "cracked_deepslate_tiles"
    cracked_nether_bricks = "cracked_nether_bricks"
    cracked_polished_blackstone_bricks = "cracked_polished_blackstone_bricks"
    cracked_stone_bricks = "cracked_stone_bricks"
    crafting_table = "crafting_table"
    creeper_head = "creeper_head"
    creeper_wall_head = "creeper_wall_head"
    crimson_button = "crimson_button"
    crimson_door = "crimson_door"
    crimson_fence = "crimson_fence"
    crimson_fence_gate = "crimson_fence_gate"
    crimson_fungus = "crimson_fungus"
    crimson_hanging_sign = "crimson_hanging_sign"
    crimson_hyphae = "crimson_hyphae"
    crimson_nylium = "crimson_nylium"
    crimson_planks = "crimson_planks"
    crimson_pressure_plate = "crimson_pressure_plate"
    crimson_roots = "crimson_roots"
    crimson_sign = "crimson_sign"
    crimson_slab = "crimson_slab"
    crimson_stairs = "crimson_stairs"
    crimson_stem = "crimson_stem"
    crimson_trapdoor = "crimson_trapdoor"
    crimson_wall_hanging_sign = "crimson_wall_hanging_sign"
    crimson_wall_sign = "crimson_wall_sign"
    crying_obsidian = "crying_obsidian"
    cut_copper = "cut_copper"
    cut_copper_slab = "cut_copper_slab"
    cut_copper_stairs = "cut_copper_stairs"
    cut_red_sandstone = "cut_red_sandstone"
    cut_red_sandstone_slab = "cut_red_sandstone_slab"
    cut_sandstone = "cut_sandstone"
    cut_sandstone_slab = "cut_sandstone_slab"
    cyan_banner = "cyan_banner"
    cyan_bed = "cyan_bed"
    cyan_candle = "cyan_candle"
    cyan_candle_cake = "cyan_candle_cake"
    cyan_carpet = "cyan_carpet"
    cyan_concrete = "cyan_concrete"
    cyan_concrete_powder = "cyan_concrete_powder"
    cyan_glazed_terracotta = "cyan_glazed_terracotta"
    cyan_shulker_box = "cyan_shulker_box"
    cyan_stained_glass = "cyan_stained_glass"
    cyan_stained_glass_pane = "cyan_stained_glass_pane"
    cyan_terracotta = "cyan_terracotta"
    cyan_wall_banner = "cyan_wall_banner"
    cyan_wool = "cyan_wool"
    damaged_anvil = "damaged_anvil"
    dandelion = "dandelion"
    dark_oak_button = "dark_oak_button"
    dark_oak_door = "dark_oak_door"
    dark_oak_fence = "dark_oak_fence"
    dark_oak_fence_gate = "dark_oak_fence_gate"
    dark_oak_hanging_sign = "dark_oak_hanging_sign"
    dark_oak_leaves = "dark_oak_leaves"
    dark_oak_log = "dark_oak_log"
    dark_oak_planks = "dark_oak_planks"
    dark_oak_pressure_plate = "dark_oak_pressure_plate"
    dark_oak_sapling = "dark_oak_sapling"
    dark_oak_sign = "dark_oak_sign"
    dark_oak_slab = "dark_oak_slab"
    dark_oak_stairs = "dark_oak_stairs"
    dark_oak_trapdoor = "dark_oak_trapdoor"
    dark_oak_wall_hanging_sign = "dark_oak_wall_hanging_sign"
    dark_oak_wall_sign = "dark_oak_wall_sign"
    dark_oak_wood = "dark_oak_wood"
    dark_prismarine = "dark_prismarine"
    dark_prismarine_slab = "dark_prismarine_slab"
    dark_prismarine_stairs = "dark_prismarine_stairs"
    daylight_detector = "daylight_detector"
    dead_brain_coral = "dead_brain_coral"
    dead_brain_coral_block = "dead_brain_coral_block"
    dead_brain_coral_fan = "dead_brain_coral_fan"
    dead_brain_coral_wall_fan = "dead_brain_coral_wall_fan"
    dead_bubble_coral = "dead_bubble_coral"
    dead_bubble_coral_block = "dead_bubble_coral_block"
    dead_bubble_coral_fan = "dead_bubble_coral_fan"
    dead_bubble_coral_wall_fan = "dead_bubble_coral_wall_fan"
    dead_bush = "dead_bush"
    dead_fire_coral = "dead_fire_coral"
    dead_fire_coral_block = "dead_fire_coral_block"
    dead_fire_coral_fan = "dead_fire_coral_fan"
    dead_fire_coral_wall_fan = "dead_fire_coral_wall_fan"
    dead_horn_coral = "dead_horn_coral"
    dead_horn_coral_block = "dead_horn_coral_block"
    dead_horn_coral_fan = "dead_horn_coral_fan"
    dead_horn_coral_wall_fan = "dead_horn_coral_wall_fan"
    dead_tube_coral = "dead_tube_coral"
    dead_tube_coral_block = "dead_tube_coral_block"
    dead_tube_coral_fan = "dead_tube_coral_fan"
    dead_tube_coral_wall_fan = "dead_tube_coral_wall_fan"
    decorated_pot = "decorated_pot"
    deepslate = "deepslate"
    deepslate_brick_slab = "deepslate_brick_slab"
    deepslate_brick_stairs = "deepslate_brick_stairs"
    deepslate_brick_wall = "deepslate_brick_wall"
    deepslate_bricks = "deepslate_bricks"
    deepslate_coal_ore = "deepslate_coal_ore"
    deepslate_copper_ore = "deepslate_copper_ore"
    deepslate_diamond_ore = "deepslate_diamond_ore"
    deepslate_emerald_ore = "deepslate_emerald_ore"
    deepslate_gold_ore = "deepslate_gold_ore"
    deepslate_iron_ore = "deepslate_iron_ore"
    deepslate_lapis_ore = "deepslate_lapis_ore"
    deepslate_redstone_ore = "deepslate_redstone_ore"
    deepslate_tile_slab = "deepslate_tile_slab"
    deepslate_tile_stairs = "deepslate_tile_stairs"
    deepslate_tile_wall = "deepslate_tile_wall"
    deepslate_tiles = "deepslate_tiles"
    detector_rail = "detector_rail"
    diamond_block = "diamond_block"
    diamond_ore = "diamond_ore"
    diorite = "diorite"
    diorite_slab = "diorite_slab"
    diorite_stairs = "diorite_stairs"
    diorite_wall = "diorite_wall"
    dirt = "dirt"
    dirt_path = "dirt_path"
    dispenser = "dispenser"
    dragon_egg = "dragon_egg"
    dragon_head = "dragon_head"
    dragon_wall_head = "dragon_wall_head"
    dried_kelp_block = "dried_kelp_block"
    dripstone_block = "dripstone_block"
    dropper = "dropper"
    emerald_block = "emerald_block"
    emerald_ore = "emerald_ore"
    enchanting_table = "enchanting_table"
    end_gateway = "end_gateway"
    end_portal = "end_portal"
    end_portal_frame = "end_portal_frame"
    end_rod = "end_rod"
    end_stone = "end_stone"
    end_stone_brick_slab = "end_stone_brick_slab"
    end_stone_brick_stairs = "end_stone_brick_stairs"
    end_stone_brick_wall = "end_stone_brick_wall"
    end_stone_bricks = "end_stone_bricks"
    ender_chest = "ender_chest"
    exposed_copper = "exposed_copper"
    exposed_cut_copper = "exposed_cut_copper"
    exposed_cut_copper_slab = "exposed_cut_copper_slab"
    exposed_cut_copper_stairs = "exposed_cut_copper_stairs"
    farmland = "farmland"
    fern = "fern"
    fire = "fire"
    fire_coral = "fire_coral"
    fire_coral_block = "fire_coral_block"
    fire_coral_fan = "fire_coral_fan"
    fire_coral_wall_fan = "fire_coral_wall_fan"
    fletching_table = "fletching_table"
    flower_pot = "flower_pot"
    flowering_azalea = "flowering_azalea"
    flowering_azalea_leaves = "flowering_azalea_leaves"
    frogspawn = "frogspawn"
    frosted_ice = "frosted_ice"
    furnace = "furnace"
    gilded_blackstone = "gilded_blackstone"
    glass = "glass"
    glass_pane = "glass_pane"
    glow_lichen = "glow_lichen"
    glowstone = "glowstone"
    gold_block = "gold_block"
    gold_ore = "gold_ore"
    granite = "granite"
    granite_slab = "granite_slab"
    granite_stairs = "granite_stairs"
    granite_wall = "granite_wall"
    grass = "grass"
    grass_block = "grass_block"
    gravel = "gravel"
    gray_banner = "gray_banner"
    gray_bed = "gray_bed"
    gray_candle = "gray_candle"
    gray_candle_cake = "gray_candle_cake"
    gray_carpet = "gray_carpet"
    gray_concrete = "gray_concrete"
    gray_concrete_powder = "gray_concrete_powder"
    gray_glazed_terracotta = "gray_glazed_terracotta"
    gray_shulker_box = "gray_shulker_box"
    gray_stained_glass = "gray_stained_glass"
    gray_stained_glass_pane = "gray_stained_glass_pane"
    gray_terracotta = "gray_terracotta"
    gray_wall_banner = "gray_wall_banner"
    gray_wool = "gray_wool"
    green_banner = "green_banner"
    green_bed = "green_bed"
    green_candle = "green_candle"
    green_candle_cake = "green_candle_cake"
    green_carpet = "green_carpet"
    green_concrete = "green_concrete"
    green_concrete_powder = "green_concrete_powder"
    green_glazed_terracotta = "green_glazed_terracotta"
    green_shulker_box = "green_shulker_box"
    green_stained_glass = "green_stained_glass"
    green_stained_glass_pane = "green_stained_glass_pane"
    green_terracotta = "green_terracotta"
    green_wall_banner = "green_wall_banner"
    green_wool = "green_wool"
    grindstone = "grindstone"
    hanging_roots = "hanging_roots"
    hay_block = "hay_block"
    heavy_weighted_pressure_plate = "heavy_weighted_pressure_plate"
    honey_block = "honey_block"
    honeycomb_block = "honeycomb_block"
    hopper = "hopper"
    horn_coral = "horn_coral"
    horn_coral_block = "horn_coral_block"
    horn_coral_fan = "horn_coral_fan"
    horn_coral_wall_fan = "horn_coral_wall_fan"
    ice = "ice"
    infested_chiseled_stone_bricks = "infested_chiseled_stone_bricks"
    infested_cobblestone = "infested_cobblestone"
    infested_cracked_stone_bricks = "infested_cracked_stone_bricks"
    infested_deepslate = "infested_deepslate"
    infested_mossy_stone_bricks = "infested_mossy_stone_bricks"
    infested_stone = "infested_stone"
    infested_stone_bricks = "infested_stone_bricks"
    iron_bars = "iron_bars"
    iron_block = "iron_block"
    iron_door = "iron_door"
    iron_ore = "iron_ore"
    iron_trapdoor = "iron_trapdoor"
    jack_o_lantern = "jack_o_lantern"
    jigsaw = "jigsaw"
    jukebox = "jukebox"
    jungle_button = "jungle_button"
    jungle_door = "jungle_door"
    jungle_fence = "jungle_fence"
    jungle_fence_gate = "jungle_fence_gate"
    jungle_hanging_sign = "jungle_hanging_sign"
    jungle_leaves = "jungle_leaves"
    jungle_log = "jungle_log"
    jungle_planks = "jungle_planks"
    jungle_pressure_plate = "jungle_pressure_plate"
    jungle_sapling = "jungle_sapling"
    jungle_sign = "jungle_sign"
    jungle_slab = "jungle_slab"
    jungle_stairs = "jungle_stairs"
    jungle_trapdoor = "jungle_trapdoor"
    jungle_wall_hanging_sign = "jungle_wall_hanging_sign"
    jungle_wall_sign = "jungle_wall_sign"
    jungle_wood = "jungle_wood"
    kelp = "kelp"
    kelp_plant = "kelp_plant"
    ladder = "ladder"
    lantern = "lantern"
    lapis_block = "lapis_block"
    lapis_ore = "lapis_ore"
    large_amethyst_bud = "large_amethyst_bud"
    large_fern = "large_fern"
    lava = "lava"
    lava_cauldron = "lava_cauldron"
    lectern = "lectern"
    lever = "lever"
    light = "light"
    light_blue_banner = "light_blue_banner"
    light_blue_bed = "light_blue_bed"
    light_blue_candle = "light_blue_candle"
    light_blue_candle_cake = "light_blue_candle_cake"
    light_blue_carpet = "light_blue_carpet"
    light_blue_concrete = "light_blue_concrete"
    light_blue_concrete_powder = "light_blue_concrete_powder"
    light_blue_glazed_terracotta = "light_blue_glazed_terracotta"
    light_blue_shulker_box = "light_blue_shulker_box"
    light_blue_stained_glass = "light_blue_stained_glass"
    light_blue_stained_glass_pane = "light_blue_stained_glass_pane"
    light_blue_terracotta = "light_blue_terracotta"
    light_blue_wall_banner = "light_blue_wall_banner"
    light_blue_wool = "light_blue_wool"
    light_gray_banner = "light_gray_banner"
    light_gray_bed = "light_gray_bed"
    light_gray_candle = "light_gray_candle"
    light_gray_candle_cake = "light_gray_candle_cake"
    light_gray_carpet = "light_gray_carpet"
    light_gray_concrete = "light_gray_concrete"
    light_gray_concrete_powder = "light_gray_concrete_powder"
    light_gray_glazed_terracotta = "light_gray_glazed_terracotta"
    light_gray_shulker_box = "light_gray_shulker_box"
    light_gray_stained_glass = "light_gray_stained_glass"
    light_gray_stained_glass_pane = "light_gray_stained_glass_pane"
    light_gray_terracotta = "light_gray_terracotta"
    light_gray_wall_banner = "light_gray_wall_banner"
    light_gray_wool = "light_gray_wool"
    light_weighted_pressure_plate = "light_weighted_pressure_plate"
    lightning_rod = "lightning_rod"
    lilac = "lilac"
    lily_of_the_valley = "lily_of_the_valley"
    lily_pad = "lily_pad"
    lime_banner = "lime_banner"
    lime_bed = "lime_bed"
    lime_candle = "lime_candle"
    lime_candle_cake = "lime_candle_cake"
    lime_carpet = "lime_carpet"
    lime_concrete = "lime_concrete"
    lime_concrete_powder = "lime_concrete_powder"
    lime_glazed_terracotta = "lime_glazed_terracotta"
    lime_shulker_box = "lime_shulker_box"
    lime_stained_glass = "lime_stained_glass"
    lime_stained_glass_pane = "lime_stained_glass_pane"
    lime_terracotta = "lime_terracotta"
    lime_wall_banner = "lime_wall_banner"
    lime_wool = "lime_wool"
    lodestone = "lodestone"
    loom = "loom"
    magenta_banner = "magenta_banner"
    magenta_bed = "magenta_bed"
    magenta_candle = "magenta_candle"
    magenta_candle_cake = "magenta_candle_cake"
    magenta_carpet = "magenta_carpet"
    magenta_concrete = "magenta_concrete"
    magenta_concrete_powder = "magenta_concrete_powder"
    magenta_glazed_terracotta = "magenta_glazed_terracotta"
    magenta_shulker_box = "magenta_shulker_box"
    magenta_stained_glass = "magenta_stained_glass"
    magenta_stained_glass_pane = "magenta_stained_glass_pane"
    magenta_terracotta = "magenta_terracotta"
    magenta_wall_banner = "magenta_wall_banner"
    magenta_wool = "magenta_wool"
    magma_block = "magma_block"
    mangrove_button = "mangrove_button"
    mangrove_door = "mangrove_door"
    mangrove_fence = "mangrove_fence"
    mangrove_fence_gate = "mangrove_fence_gate"
    mangrove_hanging_sign = "mangrove_hanging_sign"
    mangrove_leaves = "mangrove_leaves"
    mangrove_log = "mangrove_log"
    mangrove_planks = "mangrove_planks"
    mangrove_pressure_plate = "mangrove_pressure_plate"
    mangrove_propagule = "mangrove_propagule"
    mangrove_roots = "mangrove_roots"
    mangrove_sign = "mangrove_sign"
    mangrove_slab = "mangrove_slab"
    mangrove_stairs = "mangrove_stairs"
    mangrove_trapdoor = "mangrove_trapdoor"
    mangrove_wall_hanging_sign = "mangrove_wall_hanging_sign"
    mangrove_wall_sign = "mangrove_wall_sign"
    mangrove_wood = "mangrove_wood"
    medium_amethyst_bud = "medium_amethyst_bud"
    melon = "melon"
    melon_stem = "melon_stem"
    moss_block = "moss_block"
    moss_carpet = "moss_carpet"
    mossy_cobblestone = "mossy_cobblestone"
    mossy_cobblestone_slab = "mossy_cobblestone_slab"
    mossy_cobblestone_stairs = "mossy_cobblestone_stairs"
    mossy_cobblestone_wall = "mossy_cobblestone_wall"
    mossy_stone_brick_slab = "mossy_stone_brick_slab"
    mossy_stone_brick_stairs = "mossy_stone_brick_stairs"
    mossy_stone_brick_wall = "mossy_stone_brick_wall"
    mossy_stone_bricks = "mossy_stone_bricks"
    moving_piston = "moving_piston"
    mud = "mud"
    mud_brick_slab = "mud_brick_slab"
    mud_brick_stairs = "mud_brick_stairs"
    mud_brick_wall = "mud_brick_wall"
    mud_bricks = "mud_bricks"
    muddy_mangrove_roots = "muddy_mangrove_roots"
    mushroom_stem = "mushroom_stem"
    mycelium = "mycelium"
    nether_brick_fence = "nether_brick_fence"
    nether_brick_slab = "nether_brick_slab"
    nether_brick_stairs = "nether_brick_stairs"
    nether_brick_wall = "nether_brick_wall"
    nether_bricks = "nether_bricks"
    nether_gold_ore = "nether_gold_ore"
    nether_portal = "nether_portal"
    nether_quartz_ore = "nether_quartz_ore"
    nether_sprouts = "nether_sprouts"
    nether_wart = "nether_wart"
    nether_wart_block = "nether_wart_block"
    netherite_block = "netherite_block"
    netherrack = "netherrack"
    note_block = "note_block"
    oak_button = "oak_button"
    oak_door = "oak_door"
    oak_fence = "oak_fence"
    oak_fence_gate = "oak_fence_gate"
    oak_hanging_sign = "oak_hanging_sign"
    oak_leaves = "oak_leaves"
    oak_log = "oak_log"
    oak_planks = "oak_planks"
    oak_pressure_plate = "oak_pressure_plate"
    oak_sapling = "oak_sapling"
    oak_sign = "oak_sign"
    oak_slab = "oak_slab"
    oak_stairs = "oak_stairs"
    oak_trapdoor = "oak_trapdoor"
    oak_wall_hanging_sign = "oak_wall_hanging_sign"
    oak_wall_sign = "oak_wall_sign"
    oak_wood = "oak_wood"
    observer = "observer"
    obsidian = "obsidian"
    ochre_froglight = "ochre_froglight"
    orange_banner = "orange_banner"
    orange_bed = "orange_bed"
    orange_candle = "orange_candle"
    orange_candle_cake = "orange_candle_cake"
    orange_carpet = "orange_carpet"
    orange_concrete = "orange_concrete"
    orange_concrete_powder = "orange_concrete_powder"
    orange_glazed_terracotta = "orange_glazed_terracotta"
    orange_shulker_box = "orange_shulker_box"
    orange_stained_glass = "orange_stained_glass"
    orange_stained_glass_pane = "orange_stained_glass_pane"
    orange_terracotta = "orange_terracotta"
    orange_tulip = "orange_tulip"
    orange_wall_banner = "orange_wall_banner"
    orange_wool = "orange_wool"
    oxeye_daisy = "oxeye_daisy"
    oxidized_copper = "oxidized_copper"
    oxidized_cut_copper = "oxidized_cut_copper"
    oxidized_cut_copper_slab = "oxidized_cut_copper_slab"
    oxidized_cut_copper_stairs = "oxidized_cut_copper_stairs"
    packed_ice = "packed_ice"
    packed_mud = "packed_mud"
    pearlescent_froglight = "pearlescent_froglight"
    peony = "peony"
    petrified_oak_slab = "petrified_oak_slab"
    piglin_head = "piglin_head"
    piglin_wall_head = "piglin_wall_head"
    pink_banner = "pink_banner"
    pink_bed = "pink_bed"
    pink_candle = "pink_candle"
    pink_candle_cake = "pink_candle_cake"
    pink_carpet = "pink_carpet"
    pink_concrete = "pink_concrete"
    pink_concrete_powder = "pink_concrete_powder"
    pink_glazed_terracotta = "pink_glazed_terracotta"
    pink_petals = "pink_petals"
    pink_shulker_box = "pink_shulker_box"
    pink_stained_glass = "pink_stained_glass"
    pink_stained_glass_pane = "pink_stained_glass_pane"
    pink_terracotta = "pink_terracotta"
    pink_tulip = "pink_tulip"
    pink_wall_banner = "pink_wall_banner"
    pink_wool = "pink_wool"
    piston = "piston"
    piston_head = "piston_head"
    pitcher_crop = "pitcher_crop"
    pitcher_plant = "pitcher_plant"
    player_head = "player_head"
    player_wall_head = "player_wall_head"
    podzol = "podzol"
    pointed_dripstone = "pointed_dripstone"
    polished_andesite = "polished_andesite"
    polished_andesite_slab = "polished_andesite_slab"
    polished_andesite_stairs = "polished_andesite_stairs"
    polished_basalt = "polished_basalt"
    polished_blackstone = "polished_blackstone"
    polished_blackstone_brick_slab = "polished_blackstone_brick_slab"
    polished_blackstone_brick_stairs = "polished_blackstone_brick_stairs"
    polished_blackstone_brick_wall = "polished_blackstone_brick_wall"
    polished_blackstone_bricks = "polished_blackstone_bricks"
    polished_blackstone_button = "polished_blackstone_button"
    polished_blackstone_pressure_plate = "polished_blackstone_pressure_plate"
    polished_blackstone_slab = "polished_blackstone_slab"
    polished_blackstone_stairs = "polished_blackstone_stairs"
    polished_blackstone_wall = "polished_blackstone_wall"
    polished_deepslate = "polished_deepslate"
    polished_deepslate_slab = "polished_deepslate_slab"
    polished_deepslate_stairs = "polished_deepslate_stairs"
    polished_deepslate_wall = "polished_deepslate_wall"
    polished_diorite = "polished_diorite"
    polished_diorite_slab = "polished_diorite_slab"
    polished_diorite_stairs = "polished_diorite_stairs"
    polished_granite = "polished_granite"
    polished_granite_slab = "polished_granite_slab"
    polished_granite_stairs = "polished_granite_stairs"
    poppy = "poppy"
    potatoes = "potatoes"
    potted_acacia_sapling = "potted_acacia_sapling"
    potted_allium = "potted_allium"
    potted_azalea_bush = "potted_azalea_bush"
    potted_azure_bluet = "potted_azure_bluet"
    potted_bamboo = "potted_bamboo"
    potted_birch_sapling = "potted_birch_sapling"
    potted_blue_orchid = "potted_blue_orchid"
    potted_brown_mushroom = "potted_brown_mushroom"
    potted_cactus = "potted_cactus"
    potted_cherry_sapling = "potted_cherry_sapling"
    potted_cornflower = "potted_cornflower"
    potted_crimson_fungus = "potted_crimson_fungus"
    potted_crimson_roots = "potted_crimson_roots"
    potted_dandelion = "potted_dandelion"
    potted_dark_oak_sapling = "potted_dark_oak_sapling"
    potted_dead_bush = "potted_dead_bush"
    potted_fern = "potted_fern"
    potted_flowering_azalea_bush = "potted_flowering_azalea_bush"
    potted_jungle_sapling = "potted_jungle_sapling"
    potted_lily_of_the_valley = "potted_lily_of_the_valley"
    potted_mangrove_propagule = "potted_mangrove_propagule"
    potted_oak_sapling = "potted_oak_sapling"
    potted_orange_tulip = "potted_orange_tulip"
    potted_oxeye_daisy = "potted_oxeye_daisy"
    potted_pink_tulip = "potted_pink_tulip"
    potted_poppy = "potted_poppy"
    potted_red_mushroom = "potted_red_mushroom"
    potted_red_tulip = "potted_red_tulip"
    potted_spruce_sapling = "potted_spruce_sapling"
    potted_torchflower = "potted_torchflower"
    potted_warped_fungus = "potted_warped_fungus"
    potted_warped_roots = "potted_warped_roots"
    potted_white_tulip = "potted_white_tulip"
    potted_wither_rose = "potted_wither_rose"
    powder_snow = "powder_snow"
    powder_snow_cauldron = "powder_snow_cauldron"
    powered_rail = "powered_rail"
    prismarine = "prismarine"
    prismarine_brick_slab = "prismarine_brick_slab"
    prismarine_brick_stairs = "prismarine_brick_stairs"
    prismarine_bricks = "prismarine_bricks"
    prismarine_slab = "prismarine_slab"
    prismarine_stairs = "prismarine_stairs"
    prismarine_wall = "prismarine_wall"
    pumpkin = "pumpkin"
    pumpkin_stem = "pumpkin_stem"
    purple_banner = "purple_banner"
    purple_bed = "purple_bed"
    purple_candle = "purple_candle"
    purple_candle_cake = "purple_candle_cake"
    purple_carpet = "purple_carpet"
    purple_concrete = "purple_concrete"
    purple_concrete_powder = "purple_concrete_powder"
    purple_glazed_terracotta = "purple_glazed_terracotta"
    purple_shulker_box = "purple_shulker_box"
    purple_stained_glass = "purple_stained_glass"
    purple_stained_glass_pane = "purple_stained_glass_pane"
    purple_terracotta = "purple_terracotta"
    purple_wall_banner = "purple_wall_banner"
    purple_wool = "purple_wool"
    purpur_block = "purpur_block"
    purpur_pillar = "purpur_pillar"
    purpur_slab = "purpur_slab"
    purpur_stairs = "purpur_stairs"
    quartz_block = "quartz_block"
    quartz_bricks = "quartz_bricks"
    quartz_pillar = "quartz_pillar"
    quartz_slab = "quartz_slab"
    quartz_stairs = "quartz_stairs"
    rail = "rail"
    raw_copper_block = "raw_copper_block"
    raw_gold_block = "raw_gold_block"
    raw_iron_block = "raw_iron_block"
    red_banner = "red_banner"
    red_bed = "red_bed"
    red_candle = "red_candle"
    red_candle_cake = "red_candle_cake"
    red_carpet = "red_carpet"
    red_concrete = "red_concrete"
    red_concrete_powder = "red_concrete_powder"
    red_glazed_terracotta = "red_glazed_terracotta"
    red_mushroom = "red_mushroom"
    red_mushroom_block = "red_mushroom_block"
    red_nether_brick_slab = "red_nether_brick_slab"
    red_nether_brick_stairs = "red_nether_brick_stairs"
    red_nether_brick_wall = "red_nether_brick_wall"
    red_nether_bricks = "red_nether_bricks"
    red_sand = "red_sand"
    red_sandstone = "red_sandstone"
    red_sandstone_slab = "red_sandstone_slab"
    red_sandstone_stairs = "red_sandstone_stairs"
    red_sandstone_wall = "red_sandstone_wall"
    red_shulker_box = "red_shulker_box"
    red_stained_glass = "red_stained_glass"
    red_stained_glass_pane = "red_stained_glass_pane"
    red_terracotta = "red_terracotta"
    red_tulip = "red_tulip"
    red_wall_banner = "red_wall_banner"
    red_wool = "red_wool"
    redstone_block = "redstone_block"
    redstone_lamp = "redstone_lamp"
    redstone_ore = "redstone_ore"
    redstone_torch = "redstone_torch"
    redstone_wall_torch = "redstone_wall_torch"
    redstone_wire = "redstone_wire"
    reinforced_deepslate = "reinforced_deepslate"
    repeater = "repeater"
    repeating_command_block = "repeating_command_block"
    respawn_anchor = "respawn_anchor"
    rooted_dirt = "rooted_dirt"
    rose_bush = "rose_bush"
    sand = "sand"
    sandstone = "sandstone"
    sandstone_slab = "sandstone_slab"
    sandstone_stairs = "sandstone_stairs"
    sandstone_wall = "sandstone_wall"
    scaffolding = "scaffolding"
    sculk = "sculk"
    sculk_catalyst = "sculk_catalyst"
    sculk_sensor = "sculk_sensor"
    sculk_shrieker = "sculk_shrieker"
    sculk_vein = "sculk_vein"
    sea_lantern = "sea_lantern"
    sea_pickle = "sea_pickle"
    seagrass = "seagrass"
    shroomlight = "shroomlight"
    shulker_box = "shulker_box"
    skeleton_skull = "skeleton_skull"
    skeleton_wall_skull = "skeleton_wall_skull"
    slime_block = "slime_block"
    small_amethyst_bud = "small_amethyst_bud"
    small_dripleaf = "small_dripleaf"
    smithing_table = "smithing_table"
    smoker = "smoker"
    smooth_basalt = "smooth_basalt"
    smooth_quartz = "smooth_quartz"
    smooth_quartz_slab = "smooth_quartz_slab"
    smooth_quartz_stairs = "smooth_quartz_stairs"
    smooth_red_sandstone = "smooth_red_sandstone"
    smooth_red_sandstone_slab = "smooth_red_sandstone_slab"
    smooth_red_sandstone_stairs = "smooth_red_sandstone_stairs"
    smooth_sandstone = "smooth_sandstone"
    smooth_sandstone_slab = "smooth_sandstone_slab"
    smooth_sandstone_stairs = "smooth_sandstone_stairs"
    smooth_stone = "smooth_stone"
    smooth_stone_slab = "smooth_stone_slab"
    sniffer_egg = "sniffer_egg"
    snow = "snow"
    snow_block = "snow_block"
    soul_campfire = "soul_campfire"
    soul_fire = "soul_fire"
    soul_lantern = "soul_lantern"
    soul_sand = "soul_sand"
    soul_soil = "soul_soil"
    soul_torch = "soul_torch"
    soul_wall_torch = "soul_wall_torch"
    spawner = "spawner"
    sponge = "sponge"
    spore_blossom = "spore_blossom"
    spruce_button = "spruce_button"
    spruce_door = "spruce_door"
    spruce_fence = "spruce_fence"
    spruce_fence_gate = "spruce_fence_gate"
    spruce_hanging_sign = "spruce_hanging_sign"
    spruce_leaves = "spruce_leaves"
    spruce_log = "spruce_log"
    spruce_planks = "spruce_planks"
    spruce_pressure_plate = "spruce_pressure_plate"
    spruce_sapling = "spruce_sapling"
    spruce_sign = "spruce_sign"
    spruce_slab = "spruce_slab"
    spruce_stairs = "spruce_stairs"
    spruce_trapdoor = "spruce_trapdoor"
    spruce_wall_hanging_sign = "spruce_wall_hanging_sign"
    spruce_wall_sign = "spruce_wall_sign"
    spruce_wood = "spruce_wood"
    sticky_piston = "sticky_piston"
    stone = "stone"
    stone_brick_slab = "stone_brick_slab"
    stone_brick_stairs = "stone_brick_stairs"
    stone_brick_wall = "stone_brick_wall"
    stone_bricks = "stone_bricks"
    stone_button = "stone_button"
    stone_pressure_plate = "stone_pressure_plate"
    stone_slab = "stone_slab"
    stone_stairs = "stone_stairs"
    stonecutter = "stonecutter"
    stripped_acacia_log = "stripped_acacia_log"
    stripped_acacia_wood = "stripped_acacia_wood"
    stripped_bamboo_block = "stripped_bamboo_block"
    stripped_birch_log = "stripped_birch_log"
    stripped_birch_wood = "stripped_birch_wood"
    stripped_cherry_log = "stripped_cherry_log"
    stripped_cherry_wood = "stripped_cherry_wood"
    stripped_crimson_hyphae = "stripped_crimson_hyphae"
    stripped_crimson_stem = "stripped_crimson_stem"
    stripped_dark_oak_log = "stripped_dark_oak_log"
    stripped_dark_oak_wood = "stripped_dark_oak_wood"
    stripped_jungle_log = "stripped_jungle_log"
    stripped_jungle_wood = "stripped_jungle_wood"
    stripped_mangrove_log = "stripped_mangrove_log"
    stripped_mangrove_wood = "stripped_mangrove_wood"
    stripped_oak_log = "stripped_oak_log"
    stripped_oak_wood = "stripped_oak_wood"
    stripped_spruce_log = "stripped_spruce_log"
    stripped_spruce_wood = "stripped_spruce_wood"
    stripped_warped_hyphae = "stripped_warped_hyphae"
    stripped_warped_stem = "stripped_warped_stem"
    structure_block = "structure_block"
    structure_void = "structure_void"
    sugar_cane = "sugar_cane"
    sunflower = "sunflower"
    suspicious_gravel = "suspicious_gravel"
    suspicious_sand = "suspicious_sand"
    sweet_berry_bush = "sweet_berry_bush"
    tall_grass = "tall_grass"
    tall_seagrass = "tall_seagrass"
    target = "target"
    terracotta = "terracotta"
    tinted_glass = "tinted_glass"
    tnt = "tnt"
    torch = "torch"
    torchflower = "torchflower"
    torchflower_crop = "torchflower_crop"
    trapped_chest = "trapped_chest"
    tripwire = "tripwire"
    tripwire_hook = "tripwire_hook"
    tube_coral = "tube_coral"
    tube_coral_block = "tube_coral_block"
    tube_coral_fan = "tube_coral_fan"
    tube_coral_wall_fan = "tube_coral_wall_fan"
    tuff = "tuff"
    turtle_egg = "turtle_egg"
    twisting_vines = "twisting_vines"
    twisting_vines_plant = "twisting_vines_plant"
    verdant_froglight = "verdant_froglight"
    vine = "vine"
    void_air = "void_air"
    wall_torch = "wall_torch"
    warped_button = "warped_button"
    warped_door = "warped_door"
    warped_fence = "warped_fence"
    warped_fence_gate = "warped_fence_gate"
    warped_fungus = "warped_fungus"
    warped_hanging_sign = "warped_hanging_sign"
    warped_hyphae = "warped_hyphae"
    warped_nylium = "warped_nylium"
    warped_planks = "warped_planks"
    warped_pressure_plate = "warped_pressure_plate"
    warped_roots = "warped_roots"
    warped_sign = "warped_sign"
    warped_slab = "warped_slab"
    warped_stairs = "warped_stairs"
    warped_stem = "warped_stem"
    warped_trapdoor = "warped_trapdoor"
    warped_wall_hanging_sign = "warped_wall_hanging_sign"
    warped_wall_sign = "warped_wall_sign"
    warped_wart_block = "warped_wart_block"
    water = "water"
    water_cauldron = "water_cauldron"
    waxed_copper_block = "waxed_copper_block"
    waxed_cut_copper = "waxed_cut_copper"
    waxed_cut_copper_slab = "waxed_cut_copper_slab"
    waxed_cut_copper_stairs = "waxed_cut_copper_stairs"
    waxed_exposed_copper = "waxed_exposed_copper"
    waxed_exposed_cut_copper = "waxed_exposed_cut_copper"
    waxed_exposed_cut_copper_slab = "waxed_exposed_cut_copper_slab"
    waxed_exposed_cut_copper_stairs = "waxed_exposed_cut_copper_stairs"
    waxed_oxidized_copper = "waxed_oxidized_copper"
    waxed_oxidized_cut_copper = "waxed_oxidized_cut_copper"
    waxed_oxidized_cut_copper_slab = "waxed_oxidized_cut_copper_slab"
    waxed_oxidized_cut_copper_stairs = "waxed_oxidized_cut_copper_stairs"
    waxed_weathered_copper = "waxed_weathered_copper"
    waxed_weathered_cut_copper = "waxed_weathered_cut_copper"
    waxed_weathered_cut_copper_slab = "waxed_weathered_cut_copper_slab"
    waxed_weathered_cut_copper_stairs = "waxed_weathered_cut_copper_stairs"
    weathered_copper = "weathered_copper"
    weathered_cut_copper = "weathered_cut_copper"
    weathered_cut_copper_slab = "weathered_cut_copper_slab"
    weathered_cut_copper_stairs = "weathered_cut_copper_stairs"
    weeping_vines = "weeping_vines"
    weeping_vines_plant = "weeping_vines_plant"
    wet_sponge = "wet_sponge"
    wheat = "wheat"
    white_banner = "white_banner"
    white_bed = "white_bed"
    white_candle = "white_candle"
    white_candle_cake = "white_candle_cake"
    white_carpet = "white_carpet"
    white_concrete = "white_concrete"
    white_concrete_powder = "white_concrete_powder"
    white_glazed_terracotta = "white_glazed_terracotta"
    white_shulker_box = "white_shulker_box"
    white_stained_glass = "white_stained_glass"
    white_stained_glass_pane = "white_stained_glass_pane"
    white_terracotta = "white_terracotta"
    white_tulip = "white_tulip"
    white_wall_banner = "white_wall_banner"
    white_wool = "white_wool"
    wither_rose = "wither_rose"
    wither_skeleton_skull = "wither_skeleton_skull"
    wither_skeleton_wall_skull = "wither_skeleton_wall_skull"
    yellow_banner = "yellow_banner"
    yellow_bed = "yellow_bed"
    yellow_candle = "yellow_candle"
    yellow_candle_cake = "yellow_candle_cake"
    yellow_carpet = "yellow_carpet"
    yellow_concrete = "yellow_concrete"
    yellow_concrete_powder = "yellow_concrete_powder"
    yellow_glazed_terracotta = "yellow_glazed_terracotta"
    yellow_shulker_box = "yellow_shulker_box"
    yellow_stained_glass = "yellow_stained_glass"
    yellow_stained_glass_pane = "yellow_stained_glass_pane"
    yellow_terracotta = "yellow_terracotta"
    yellow_wall_banner = "yellow_wall_banner"
    yellow_wool = "yellow_wool"
    zombie_head = "zombie_head"
    zombie_wall_head = "zombie_wall_head"
